@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,14 +58,11 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "bind-gram.y"
 
 /* grecs - Gray's Extensible Configuration System
@@ -104,9 +101,8 @@ extern void grecs_bind_close_sources(void);
 
 static struct grecs_value *stmtlist_to_value(struct grecs_node *node);
 
-
-/* Line 268 of yacc.c  */
-#line 110 "bind-gram.c"
+/* Line 371 of yacc.c  */
+#line 106 "bind-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -116,11 +112,6 @@ static struct grecs_value *stmtlist_to_value(struct grecs_node *node);
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -129,11 +120,17 @@ static struct grecs_value *stmtlist_to_value(struct grecs_node *node);
 # define YYERROR_VERBOSE 1
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int grecs_bind_debug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -153,12 +150,10 @@ static struct grecs_value *stmtlist_to_value(struct grecs_node *node);
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 42 "bind-gram.y"
 
 	char *string;
@@ -169,9 +164,8 @@ typedef union YYSTYPE
 	struct { struct grecs_node *head, *tail; } node_list;
 
 
-
-/* Line 295 of yacc.c  */
-#line 175 "bind-gram.c"
+/* Line 387 of yacc.c  */
+#line 169 "bind-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define grecs_bind_stype YYSTYPE /* obsolescent; will be withdrawn */
@@ -191,12 +185,28 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
+extern YYSTYPE grecs_bind_lval;
+extern YYLTYPE grecs_bind_lloc;
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int grecs_bind_parse (void *YYPARSE_PARAM);
+#else
+int grecs_bind_parse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int grecs_bind_parse (void);
+#else
+int grecs_bind_parse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 200 "bind-gram.c"
+/* Line 390 of yacc.c  */
+#line 210 "bind-gram.c"
 
 #ifdef short
 # undef short
@@ -249,24 +259,24 @@ typedef short int grecs_bind_type_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -499,7 +509,7 @@ static const grecs_bind_type_uint8 grecs_bind_rline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const grecs_bind_tname[] =
@@ -585,10 +595,10 @@ static const grecs_bind_type_int8 grecs_bind_table[] =
        0,     0,     0,    37
 };
 
-#define grecs_bind_pact_value_is_default(grecs_bind_state) \
-  ((grecs_bind_state) == (-14))
+#define grecs_bind_pact_value_is_default(Yystate) \
+  (!!((Yystate) == (-14)))
 
-#define grecs_bind_table_value_is_error(grecs_bind_table_value) \
+#define grecs_bind_table_value_is_error(Yytable_value) \
   YYID (0)
 
 static const grecs_bind_type_int8 grecs_bind_check[] =
@@ -654,7 +664,7 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
@@ -663,27 +673,28 @@ while (YYID (0))
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -691,10 +702,46 @@ while (YYID (0))
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+grecs_bind__location_print_ (FILE *grecs_bind_o, YYLTYPE const * const grecs_bind_locp)
+#else
+static unsigned
+grecs_bind__location_print_ (grecs_bind_o, grecs_bind_locp)
+    FILE *grecs_bind_o;
+    YYLTYPE const * const grecs_bind_locp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != grecs_bind_locp->last_column ? grecs_bind_locp->last_column - 1 : 0;
+  if (0 <= grecs_bind_locp->first_line)
+    {
+      res += fprintf (grecs_bind_o, "%d", grecs_bind_locp->first_line);
+      if (0 <= grecs_bind_locp->first_column)
+        res += fprintf (grecs_bind_o, ".%d", grecs_bind_locp->first_column);
+    }
+  if (0 <= grecs_bind_locp->last_line)
+    {
+      if (grecs_bind_locp->first_line < grecs_bind_locp->last_line)
+        {
+          res += fprintf (grecs_bind_o, "-%d", grecs_bind_locp->last_line);
+          if (0 <= end_col)
+            res += fprintf (grecs_bind_o, ".%d", end_col);
+        }
+      else if (0 <= end_col && grecs_bind_locp->first_column < end_col)
+        res += fprintf (grecs_bind_o, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  grecs_bind__location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -702,7 +749,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `grecs_bind_lex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX grecs_bind_lex (YYLEX_PARAM)
 #else
@@ -767,7 +813,7 @@ grecs_bind__symbol_value_print (grecs_bind_output, grecs_bind_type, grecs_bind_v
   switch (grecs_bind_type)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1013,7 +1059,6 @@ grecs_bind_syntax_error (YYSIZE_T *grecs_bind_msg_alloc, char **grecs_bind_msg,
 {
   YYSIZE_T grecs_bind_size0 = grecs_bind_tnamerr (YY_NULL, grecs_bind_tname[grecs_bind_token]);
   YYSIZE_T grecs_bind_size = grecs_bind_size0;
-  YYSIZE_T grecs_bind_size1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *grecs_bind_format = YY_NULL;
@@ -1076,11 +1121,13 @@ grecs_bind_syntax_error (YYSIZE_T *grecs_bind_msg_alloc, char **grecs_bind_msg,
                     break;
                   }
                 grecs_bind_arg[grecs_bind_count++] = grecs_bind_tname[grecs_bind_x];
-                grecs_bind_size1 = grecs_bind_size + grecs_bind_tnamerr (YY_NULL, grecs_bind_tname[grecs_bind_x]);
-                if (! (grecs_bind_size <= grecs_bind_size1
-                       && grecs_bind_size1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                grecs_bind_size = grecs_bind_size1;
+                {
+                  YYSIZE_T grecs_bind_size1 = grecs_bind_size + grecs_bind_tnamerr (YY_NULL, grecs_bind_tname[grecs_bind_x]);
+                  if (! (grecs_bind_size <= grecs_bind_size1
+                         && grecs_bind_size1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  grecs_bind_size = grecs_bind_size1;
+                }
               }
         }
     }
@@ -1100,10 +1147,12 @@ grecs_bind_syntax_error (YYSIZE_T *grecs_bind_msg_alloc, char **grecs_bind_msg,
 # undef YYCASE_
     }
 
-  grecs_bind_size1 = grecs_bind_size + grecs_bind_strlen (grecs_bind_format);
-  if (! (grecs_bind_size <= grecs_bind_size1 && grecs_bind_size1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  grecs_bind_size = grecs_bind_size1;
+  {
+    YYSIZE_T grecs_bind_size1 = grecs_bind_size + grecs_bind_strlen (grecs_bind_format);
+    if (! (grecs_bind_size <= grecs_bind_size1 && grecs_bind_size1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    grecs_bind_size = grecs_bind_size1;
+  }
 
   if (*grecs_bind_msg_alloc < grecs_bind_size)
     {
@@ -1165,35 +1214,35 @@ grecs_bind_destruct (grecs_bind_msg, grecs_bind_type, grecs_bind_valuep, grecs_b
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int grecs_bind_parse (void *YYPARSE_PARAM);
-#else
-int grecs_bind_parse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int grecs_bind_parse (void);
-#else
-int grecs_bind_parse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int grecs_bind_char;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE grecs_bind_lval;
+YYSTYPE grecs_bind_lval YY_INITIAL_VALUE(grecs_bind_val_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE grecs_bind_lloc;
+YYLTYPE grecs_bind_lloc
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
+
 
 /* Number of syntax errors so far.  */
 int grecs_bind_nerrs;
@@ -1260,7 +1309,7 @@ grecs_bind_parse ()
   int grecs_bind_n;
   int grecs_bind_result;
   /* Lookahead token as an internal (translated) token number.  */
-  int grecs_bind_token;
+  int grecs_bind_token = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE grecs_bind_val;
@@ -1279,10 +1328,9 @@ grecs_bind_parse ()
      Keep to zero when no symbol should be popped.  */
   int grecs_bind_len = 0;
 
-  grecs_bind_token = 0;
-  grecs_bind_ss = grecs_bind_ssa;
-  grecs_bind_vs = grecs_bind_vsa;
-  grecs_bind_ls = grecs_bind_lsa;
+  grecs_bind_ssp = grecs_bind_ss = grecs_bind_ssa;
+  grecs_bind_vsp = grecs_bind_vs = grecs_bind_vsa;
+  grecs_bind_lsp = grecs_bind_ls = grecs_bind_lsa;
   grecs_bind_stacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1291,21 +1339,7 @@ grecs_bind_parse ()
   grecs_bind_errstatus = 0;
   grecs_bind_nerrs = 0;
   grecs_bind_char = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  grecs_bind_ssp = grecs_bind_ss;
-  grecs_bind_vsp = grecs_bind_vs;
-  grecs_bind_lsp = grecs_bind_ls;
-
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  grecs_bind_lloc.first_line   = grecs_bind_lloc.last_line   = 1;
-  grecs_bind_lloc.first_column = grecs_bind_lloc.last_column = 1;
-#endif
-
+  grecs_bind_lsp[0] = grecs_bind_lloc;
   goto grecs_bind_setstate;
 
 /*------------------------------------------------------------.
@@ -1451,7 +1485,9 @@ grecs_bind_backup:
   grecs_bind_char = YYEMPTY;
 
   grecs_bind_state = grecs_bind_n;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_bind_vsp = grecs_bind_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++grecs_bind_lsp = grecs_bind_lloc;
   goto grecs_bind_newstate;
 
@@ -1489,8 +1525,7 @@ grecs_bind_reduce:
   switch (grecs_bind_n)
     {
         case 2:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 62 "bind-gram.y"
     {
 		  parse_tree = grecs_node_create(grecs_node_root, &(grecs_bind_lsp[(1) - (1)]));
@@ -1500,8 +1535,7 @@ grecs_bind_reduce:
     break;
 
   case 3:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 71 "bind-gram.y"
     {
 		  (grecs_bind_val.node) = NULL;
@@ -1509,8 +1543,7 @@ grecs_bind_reduce:
     break;
 
   case 4:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 75 "bind-gram.y"
     {
 		  (grecs_bind_val.node) = (grecs_bind_vsp[(1) - (1)].node_list).head;
@@ -1518,8 +1551,7 @@ grecs_bind_reduce:
     break;
 
   case 5:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 81 "bind-gram.y"
     {
 		  (grecs_bind_val.node_list).head = (grecs_bind_val.node_list).tail = (grecs_bind_vsp[(1) - (1)].node);
@@ -1527,8 +1559,7 @@ grecs_bind_reduce:
     break;
 
   case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 85 "bind-gram.y"
     {
 		  if ((grecs_bind_vsp[(2) - (2)].node)) {
@@ -1542,8 +1573,7 @@ grecs_bind_reduce:
     break;
 
   case 9:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 101 "bind-gram.y"
     {
 		  if (strcmp((grecs_bind_vsp[(1) - (3)].string), "include") == 0 &&
@@ -1561,8 +1591,7 @@ grecs_bind_reduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 115 "bind-gram.y"
     {
 		  (grecs_bind_val.node) = grecs_node_create(grecs_node_stmt, &(grecs_bind_lsp[(1) - (2)]));
@@ -1573,8 +1602,7 @@ grecs_bind_reduce:
     break;
 
   case 11:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 122 "bind-gram.y"
     {
 		  (grecs_bind_val.node) = grecs_node_create_points(grecs_node_stmt,
@@ -1589,8 +1617,7 @@ grecs_bind_reduce:
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 135 "bind-gram.y"
     {
 		  (grecs_bind_val.node) = grecs_node_create_points(grecs_node_block,
@@ -1603,8 +1630,7 @@ grecs_bind_reduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 156 "bind-gram.y"
     {
 		  (grecs_bind_val.node) = grecs_node_create_points(grecs_node_stmt,
@@ -1616,8 +1642,7 @@ grecs_bind_reduce:
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 166 "bind-gram.y"
     {
 		  (grecs_bind_val.pvalue) = NULL;
@@ -1625,8 +1650,7 @@ grecs_bind_reduce:
     break;
 
   case 16:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 173 "bind-gram.y"
     {
 		  size_t n;
@@ -1652,8 +1676,7 @@ grecs_bind_reduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 197 "bind-gram.y"
     {
 		  (grecs_bind_val.list) = grecs_value_list_create();
@@ -1662,8 +1685,7 @@ grecs_bind_reduce:
     break;
 
   case 18:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 202 "bind-gram.y"
     {
 		  grecs_list_append((grecs_bind_vsp[(1) - (2)].list), grecs_value_ptr_from_static(&(grecs_bind_vsp[(2) - (2)].svalue)));
@@ -1671,8 +1693,7 @@ grecs_bind_reduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 208 "bind-gram.y"
     {
 		  (grecs_bind_val.svalue).type = GRECS_TYPE_STRING;
@@ -1682,8 +1703,7 @@ grecs_bind_reduce:
     break;
 
   case 22:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 220 "bind-gram.y"
     {
 		  (grecs_bind_val.svalue).type = GRECS_TYPE_LIST;
@@ -1693,8 +1713,7 @@ grecs_bind_reduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 228 "bind-gram.y"
     {
 		  (grecs_bind_val.list) = grecs_value_list_create();
@@ -1703,8 +1722,7 @@ grecs_bind_reduce:
     break;
 
   case 24:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 233 "bind-gram.y"
     {
 		  grecs_list_append((grecs_bind_vsp[(1) - (2)].list), grecs_value_ptr_from_static(&(grecs_bind_vsp[(2) - (2)].svalue)));
@@ -1712,8 +1730,7 @@ grecs_bind_reduce:
     break;
 
   case 25:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 237 "bind-gram.y"
     {
 		  grecs_list_append((grecs_bind_vsp[(1) - (4)].list), stmtlist_to_value((grecs_bind_vsp[(3) - (4)].node_list).head));
@@ -1722,9 +1739,8 @@ grecs_bind_reduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1728 "bind-gram.c"
+/* Line 1792 of yacc.c  */
+#line 1744 "bind-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter grecs_bind_char, and that requires
@@ -1889,7 +1905,9 @@ grecs_bind_errlab1:
       YY_STACK_PRINT (grecs_bind_ss, grecs_bind_ssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_bind_vsp = grecs_bind_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   grecs_bind_error_range[2] = grecs_bind_lloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -1960,8 +1978,7 @@ grecs_bind_return:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 243 "bind-gram.y"
 
 
@@ -2044,4 +2061,3 @@ stmtlist_to_value(struct grecs_node *node)
 	grecs_txtacc_free(acc);
 	return val;
 }
-
