@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,14 +58,11 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "dhcpd-gram.y"
 
 /* grecs - Gray's Extensible Configuration System
@@ -117,9 +114,8 @@ make_string_value(char *string)
 }
 
 
-
-/* Line 268 of yacc.c  */
-#line 123 "dhcpd-gram.c"
+/* Line 371 of yacc.c  */
+#line 119 "dhcpd-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -129,11 +125,6 @@ make_string_value(char *string)
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -142,11 +133,17 @@ make_string_value(char *string)
 # define YYERROR_VERBOSE 1
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int grecs_dhcpddebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -172,12 +169,10 @@ make_string_value(char *string)
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 55 "dhcpd-gram.y"
 
 	char *string;
@@ -188,9 +183,8 @@ typedef union YYSTYPE
 	struct { struct grecs_node *head, *tail; } node_list;
 
 
-
-/* Line 295 of yacc.c  */
-#line 194 "dhcpd-gram.c"
+/* Line 387 of yacc.c  */
+#line 188 "dhcpd-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define grecs_dhcpdstype YYSTYPE /* obsolescent; will be withdrawn */
@@ -210,12 +204,28 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
+extern YYSTYPE grecs_dhcpdlval;
+extern YYLTYPE grecs_dhcpdlloc;
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int grecs_dhcpdparse (void *YYPARSE_PARAM);
+#else
+int grecs_dhcpdparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int grecs_dhcpdparse (void);
+#else
+int grecs_dhcpdparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 219 "dhcpd-gram.c"
+/* Line 390 of yacc.c  */
+#line 229 "dhcpd-gram.c"
 
 #ifdef short
 # undef short
@@ -268,24 +278,24 @@ typedef short int grecs_dhcpdtype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -524,7 +534,7 @@ static const grecs_dhcpdtype_uint16 grecs_dhcpdrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const grecs_dhcpdtname[] =
@@ -620,10 +630,10 @@ static const grecs_dhcpdtype_int8 grecs_dhcpdtable[] =
       40,    48,    53,    49,    57,    54,    23,    58,    30,    52
 };
 
-#define grecs_dhcpdpact_value_is_default(grecs_dhcpdstate) \
-  ((grecs_dhcpdstate) == (-29))
+#define grecs_dhcpdpact_value_is_default(Yystate) \
+  (!!((Yystate) == (-29)))
 
-#define grecs_dhcpdtable_value_is_error(grecs_dhcpdtable_value) \
+#define grecs_dhcpdtable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const grecs_dhcpdtype_uint8 grecs_dhcpdcheck[] =
@@ -690,7 +700,7 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
@@ -699,27 +709,28 @@ while (YYID (0))
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -727,10 +738,46 @@ while (YYID (0))
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+grecs_dhcpd_location_print_ (FILE *grecs_dhcpdo, YYLTYPE const * const grecs_dhcpdlocp)
+#else
+static unsigned
+grecs_dhcpd_location_print_ (grecs_dhcpdo, grecs_dhcpdlocp)
+    FILE *grecs_dhcpdo;
+    YYLTYPE const * const grecs_dhcpdlocp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != grecs_dhcpdlocp->last_column ? grecs_dhcpdlocp->last_column - 1 : 0;
+  if (0 <= grecs_dhcpdlocp->first_line)
+    {
+      res += fprintf (grecs_dhcpdo, "%d", grecs_dhcpdlocp->first_line);
+      if (0 <= grecs_dhcpdlocp->first_column)
+        res += fprintf (grecs_dhcpdo, ".%d", grecs_dhcpdlocp->first_column);
+    }
+  if (0 <= grecs_dhcpdlocp->last_line)
+    {
+      if (grecs_dhcpdlocp->first_line < grecs_dhcpdlocp->last_line)
+        {
+          res += fprintf (grecs_dhcpdo, "-%d", grecs_dhcpdlocp->last_line);
+          if (0 <= end_col)
+            res += fprintf (grecs_dhcpdo, ".%d", end_col);
+        }
+      else if (0 <= end_col && grecs_dhcpdlocp->first_column < end_col)
+        res += fprintf (grecs_dhcpdo, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  grecs_dhcpd_location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -738,7 +785,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `grecs_dhcpdlex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX grecs_dhcpdlex (YYLEX_PARAM)
 #else
@@ -803,7 +849,7 @@ grecs_dhcpd_symbol_value_print (grecs_dhcpdoutput, grecs_dhcpdtype, grecs_dhcpdv
   switch (grecs_dhcpdtype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1049,7 +1095,6 @@ grecs_dhcpdsyntax_error (YYSIZE_T *grecs_dhcpdmsg_alloc, char **grecs_dhcpdmsg,
 {
   YYSIZE_T grecs_dhcpdsize0 = grecs_dhcpdtnamerr (YY_NULL, grecs_dhcpdtname[grecs_dhcpdtoken]);
   YYSIZE_T grecs_dhcpdsize = grecs_dhcpdsize0;
-  YYSIZE_T grecs_dhcpdsize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *grecs_dhcpdformat = YY_NULL;
@@ -1112,11 +1157,13 @@ grecs_dhcpdsyntax_error (YYSIZE_T *grecs_dhcpdmsg_alloc, char **grecs_dhcpdmsg,
                     break;
                   }
                 grecs_dhcpdarg[grecs_dhcpdcount++] = grecs_dhcpdtname[grecs_dhcpdx];
-                grecs_dhcpdsize1 = grecs_dhcpdsize + grecs_dhcpdtnamerr (YY_NULL, grecs_dhcpdtname[grecs_dhcpdx]);
-                if (! (grecs_dhcpdsize <= grecs_dhcpdsize1
-                       && grecs_dhcpdsize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                grecs_dhcpdsize = grecs_dhcpdsize1;
+                {
+                  YYSIZE_T grecs_dhcpdsize1 = grecs_dhcpdsize + grecs_dhcpdtnamerr (YY_NULL, grecs_dhcpdtname[grecs_dhcpdx]);
+                  if (! (grecs_dhcpdsize <= grecs_dhcpdsize1
+                         && grecs_dhcpdsize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  grecs_dhcpdsize = grecs_dhcpdsize1;
+                }
               }
         }
     }
@@ -1136,10 +1183,12 @@ grecs_dhcpdsyntax_error (YYSIZE_T *grecs_dhcpdmsg_alloc, char **grecs_dhcpdmsg,
 # undef YYCASE_
     }
 
-  grecs_dhcpdsize1 = grecs_dhcpdsize + grecs_dhcpdstrlen (grecs_dhcpdformat);
-  if (! (grecs_dhcpdsize <= grecs_dhcpdsize1 && grecs_dhcpdsize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  grecs_dhcpdsize = grecs_dhcpdsize1;
+  {
+    YYSIZE_T grecs_dhcpdsize1 = grecs_dhcpdsize + grecs_dhcpdstrlen (grecs_dhcpdformat);
+    if (! (grecs_dhcpdsize <= grecs_dhcpdsize1 && grecs_dhcpdsize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    grecs_dhcpdsize = grecs_dhcpdsize1;
+  }
 
   if (*grecs_dhcpdmsg_alloc < grecs_dhcpdsize)
     {
@@ -1201,35 +1250,35 @@ grecs_dhcpddestruct (grecs_dhcpdmsg, grecs_dhcpdtype, grecs_dhcpdvaluep, grecs_d
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int grecs_dhcpdparse (void *YYPARSE_PARAM);
-#else
-int grecs_dhcpdparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int grecs_dhcpdparse (void);
-#else
-int grecs_dhcpdparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int grecs_dhcpdchar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE grecs_dhcpdlval;
+YYSTYPE grecs_dhcpdlval YY_INITIAL_VALUE(grecs_dhcpdval_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE grecs_dhcpdlloc;
+YYLTYPE grecs_dhcpdlloc
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
+
 
 /* Number of syntax errors so far.  */
 int grecs_dhcpdnerrs;
@@ -1296,7 +1345,7 @@ grecs_dhcpdparse ()
   int grecs_dhcpdn;
   int grecs_dhcpdresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int grecs_dhcpdtoken;
+  int grecs_dhcpdtoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE grecs_dhcpdval;
@@ -1315,10 +1364,9 @@ grecs_dhcpdparse ()
      Keep to zero when no symbol should be popped.  */
   int grecs_dhcpdlen = 0;
 
-  grecs_dhcpdtoken = 0;
-  grecs_dhcpdss = grecs_dhcpdssa;
-  grecs_dhcpdvs = grecs_dhcpdvsa;
-  grecs_dhcpdls = grecs_dhcpdlsa;
+  grecs_dhcpdssp = grecs_dhcpdss = grecs_dhcpdssa;
+  grecs_dhcpdvsp = grecs_dhcpdvs = grecs_dhcpdvsa;
+  grecs_dhcpdlsp = grecs_dhcpdls = grecs_dhcpdlsa;
   grecs_dhcpdstacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1327,21 +1375,7 @@ grecs_dhcpdparse ()
   grecs_dhcpderrstatus = 0;
   grecs_dhcpdnerrs = 0;
   grecs_dhcpdchar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  grecs_dhcpdssp = grecs_dhcpdss;
-  grecs_dhcpdvsp = grecs_dhcpdvs;
-  grecs_dhcpdlsp = grecs_dhcpdls;
-
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  grecs_dhcpdlloc.first_line   = grecs_dhcpdlloc.last_line   = 1;
-  grecs_dhcpdlloc.first_column = grecs_dhcpdlloc.last_column = 1;
-#endif
-
+  grecs_dhcpdlsp[0] = grecs_dhcpdlloc;
   goto grecs_dhcpdsetstate;
 
 /*------------------------------------------------------------.
@@ -1487,7 +1521,9 @@ grecs_dhcpdbackup:
   grecs_dhcpdchar = YYEMPTY;
 
   grecs_dhcpdstate = grecs_dhcpdn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_dhcpdvsp = grecs_dhcpdlval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++grecs_dhcpdlsp = grecs_dhcpdlloc;
   goto grecs_dhcpdnewstate;
 
@@ -1525,8 +1561,7 @@ grecs_dhcpdreduce:
   switch (grecs_dhcpdn)
     {
         case 2:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 78 "dhcpd-gram.y"
     {
 		  parse_tree = grecs_node_create(grecs_node_root, &(grecs_dhcpdlsp[(1) - (1)]));
@@ -1536,8 +1571,7 @@ grecs_dhcpdreduce:
     break;
 
   case 3:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 87 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = NULL;
@@ -1545,8 +1579,7 @@ grecs_dhcpdreduce:
     break;
 
   case 4:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 91 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = (grecs_dhcpdvsp[(1) - (1)].node_list).head;
@@ -1554,8 +1587,7 @@ grecs_dhcpdreduce:
     break;
 
   case 5:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 97 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node_list).head = (grecs_dhcpdval.node_list).tail = (grecs_dhcpdvsp[(1) - (1)].node);
@@ -1563,8 +1595,7 @@ grecs_dhcpdreduce:
     break;
 
   case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 101 "dhcpd-gram.y"
     {
 		  if ((grecs_dhcpdvsp[(2) - (2)].node)) {
@@ -1578,8 +1609,7 @@ grecs_dhcpdreduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 118 "dhcpd-gram.y"
     {
 		  if (strcmp((grecs_dhcpdvsp[(1) - (3)].string), "include") == 0 &&
@@ -1597,15 +1627,13 @@ grecs_dhcpdreduce:
     break;
 
   case 11:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 131 "dhcpd-gram.y"
     { grecs_dhcpd_begin_expr(); }
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 132 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = grecs_node_create_points(grecs_node_stmt,
@@ -1617,8 +1645,7 @@ grecs_dhcpdreduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 140 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = grecs_node_create(grecs_node_stmt, &(grecs_dhcpdlsp[(1) - (2)]));
@@ -1629,8 +1656,7 @@ grecs_dhcpdreduce:
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 149 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = grecs_node_create_points(grecs_node_block,
@@ -1643,8 +1669,7 @@ grecs_dhcpdreduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 164 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.pvalue) = NULL;
@@ -1652,8 +1677,7 @@ grecs_dhcpdreduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 171 "dhcpd-gram.y"
     {
 		  size_t n;
@@ -1679,8 +1703,7 @@ grecs_dhcpdreduce:
     break;
 
   case 20:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 195 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.list) = grecs_value_list_create();
@@ -1689,8 +1712,7 @@ grecs_dhcpdreduce:
     break;
 
   case 21:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 200 "dhcpd-gram.y"
     {
 		  grecs_list_append((grecs_dhcpdvsp[(1) - (2)].list), grecs_value_ptr_from_static(&(grecs_dhcpdvsp[(2) - (2)].svalue)));
@@ -1698,8 +1720,7 @@ grecs_dhcpdreduce:
     break;
 
   case 22:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 206 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.svalue).type = GRECS_TYPE_STRING;
@@ -1709,8 +1730,7 @@ grecs_dhcpdreduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 212 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.svalue).type = GRECS_TYPE_LIST;
@@ -1720,8 +1740,7 @@ grecs_dhcpdreduce:
     break;
 
   case 26:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 224 "dhcpd-gram.y"
     {
 		  grecs_value_t val;
@@ -1741,8 +1760,7 @@ grecs_dhcpdreduce:
     break;
 
   case 27:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 240 "dhcpd-gram.y"
     {
 		  grecs_value_t val;
@@ -1755,8 +1773,7 @@ grecs_dhcpdreduce:
     break;
 
   case 28:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 251 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = grecs_node_create_points(grecs_node_block,
@@ -1779,8 +1796,7 @@ grecs_dhcpdreduce:
     break;
 
   case 29:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 272 "dhcpd-gram.y"
     {
 		  grecs_dhcpd_begin_bool();
@@ -1788,8 +1804,7 @@ grecs_dhcpdreduce:
     break;
 
   case 30:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 278 "dhcpd-gram.y"
     {
 		  grecs_dhcpd_begin_bool();
@@ -1797,8 +1812,7 @@ grecs_dhcpdreduce:
     break;
 
   case 31:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 284 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node_list).head = (grecs_dhcpdval.node_list).tail = NULL;
@@ -1806,8 +1820,7 @@ grecs_dhcpdreduce:
     break;
 
   case 33:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 291 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node_list).head = (grecs_dhcpdval.node_list).tail = (grecs_dhcpdvsp[(1) - (1)].node);
@@ -1815,8 +1828,7 @@ grecs_dhcpdreduce:
     break;
 
   case 34:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 295 "dhcpd-gram.y"
     {
 		  if ((grecs_dhcpdvsp[(2) - (2)].node)) {
@@ -1830,8 +1842,7 @@ grecs_dhcpdreduce:
     break;
 
   case 35:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 307 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = grecs_node_create_points(grecs_node_block,
@@ -1848,8 +1859,7 @@ grecs_dhcpdreduce:
     break;
 
   case 36:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 322 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = NULL;
@@ -1857,8 +1867,7 @@ grecs_dhcpdreduce:
     break;
 
   case 38:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 329 "dhcpd-gram.y"
     {
 		  (grecs_dhcpdval.node) = grecs_node_create_points(grecs_node_block,
@@ -1875,9 +1884,8 @@ grecs_dhcpdreduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1881 "dhcpd-gram.c"
+/* Line 1792 of yacc.c  */
+#line 1889 "dhcpd-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter grecs_dhcpdchar, and that requires
@@ -2042,7 +2050,9 @@ grecs_dhcpderrlab1:
       YY_STACK_PRINT (grecs_dhcpdss, grecs_dhcpdssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_dhcpdvsp = grecs_dhcpdlval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   grecs_dhcpderror_range[2] = grecs_dhcpdlloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -2113,8 +2123,7 @@ grecs_dhcpdreturn:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 343 "dhcpd-gram.y"
 
 
@@ -2148,4 +2157,3 @@ grecs_dhcpd_parser(const char *name, int traceflags)
 	return parse_tree;
 }
 
-
