@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,14 +58,11 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "grecs-gram.y"
 
 /* grecs - Gray's Extensible Configuration System
@@ -99,9 +96,8 @@ int grecs_grecs_error(char const *s);
 
 static struct grecs_node *parse_tree;
 
-
-/* Line 268 of yacc.c  */
-#line 105 "grecs-gram.c"
+/* Line 371 of yacc.c  */
+#line 101 "grecs-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -111,11 +107,6 @@ static struct grecs_node *parse_tree;
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -124,11 +115,17 @@ static struct grecs_node *parse_tree;
 # define YYERROR_VERBOSE 1
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int grecs_grecs_debug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -150,12 +147,10 @@ static struct grecs_node *parse_tree;
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 37 "grecs-gram.y"
 
 	char *string;
@@ -166,9 +161,8 @@ typedef union YYSTYPE
 	struct { struct grecs_node *head, *tail; } node_list;
 
 
-
-/* Line 295 of yacc.c  */
-#line 172 "grecs-gram.c"
+/* Line 387 of yacc.c  */
+#line 166 "grecs-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define grecs_grecs_stype YYSTYPE /* obsolescent; will be withdrawn */
@@ -188,12 +182,28 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
+extern YYSTYPE grecs_grecs_lval;
+extern YYLTYPE grecs_grecs_lloc;
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int grecs_grecs_parse (void *YYPARSE_PARAM);
+#else
+int grecs_grecs_parse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int grecs_grecs_parse (void);
+#else
+int grecs_grecs_parse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 197 "grecs-gram.c"
+/* Line 390 of yacc.c  */
+#line 207 "grecs-gram.c"
 
 #ifdef short
 # undef short
@@ -246,24 +256,24 @@ typedef short int grecs_grecs_type_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -500,7 +510,7 @@ static const grecs_grecs_type_uint8 grecs_grecs_rline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const grecs_grecs_tname[] =
@@ -589,10 +599,10 @@ static const grecs_grecs_type_uint8 grecs_grecs_table[] =
       13,     8,     9,    10,    11,    27,     1,     0,    13,    36
 };
 
-#define grecs_grecs_pact_value_is_default(grecs_grecs_state) \
-  ((grecs_grecs_state) == (-13))
+#define grecs_grecs_pact_value_is_default(Yystate) \
+  (!!((Yystate) == (-13)))
 
-#define grecs_grecs_table_value_is_error(grecs_grecs_table_value) \
+#define grecs_grecs_table_value_is_error(Yytable_value) \
   YYID (0)
 
 static const grecs_grecs_type_int8 grecs_grecs_check[] =
@@ -657,7 +667,7 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
@@ -666,27 +676,28 @@ while (YYID (0))
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -694,10 +705,46 @@ while (YYID (0))
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+grecs_grecs__location_print_ (FILE *grecs_grecs_o, YYLTYPE const * const grecs_grecs_locp)
+#else
+static unsigned
+grecs_grecs__location_print_ (grecs_grecs_o, grecs_grecs_locp)
+    FILE *grecs_grecs_o;
+    YYLTYPE const * const grecs_grecs_locp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != grecs_grecs_locp->last_column ? grecs_grecs_locp->last_column - 1 : 0;
+  if (0 <= grecs_grecs_locp->first_line)
+    {
+      res += fprintf (grecs_grecs_o, "%d", grecs_grecs_locp->first_line);
+      if (0 <= grecs_grecs_locp->first_column)
+        res += fprintf (grecs_grecs_o, ".%d", grecs_grecs_locp->first_column);
+    }
+  if (0 <= grecs_grecs_locp->last_line)
+    {
+      if (grecs_grecs_locp->first_line < grecs_grecs_locp->last_line)
+        {
+          res += fprintf (grecs_grecs_o, "-%d", grecs_grecs_locp->last_line);
+          if (0 <= end_col)
+            res += fprintf (grecs_grecs_o, ".%d", end_col);
+        }
+      else if (0 <= end_col && grecs_grecs_locp->first_column < end_col)
+        res += fprintf (grecs_grecs_o, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  grecs_grecs__location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -705,7 +752,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `grecs_grecs_lex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX grecs_grecs_lex (YYLEX_PARAM)
 #else
@@ -770,7 +816,7 @@ grecs_grecs__symbol_value_print (grecs_grecs_output, grecs_grecs_type, grecs_gre
   switch (grecs_grecs_type)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1016,7 +1062,6 @@ grecs_grecs_syntax_error (YYSIZE_T *grecs_grecs_msg_alloc, char **grecs_grecs_ms
 {
   YYSIZE_T grecs_grecs_size0 = grecs_grecs_tnamerr (YY_NULL, grecs_grecs_tname[grecs_grecs_token]);
   YYSIZE_T grecs_grecs_size = grecs_grecs_size0;
-  YYSIZE_T grecs_grecs_size1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *grecs_grecs_format = YY_NULL;
@@ -1079,11 +1124,13 @@ grecs_grecs_syntax_error (YYSIZE_T *grecs_grecs_msg_alloc, char **grecs_grecs_ms
                     break;
                   }
                 grecs_grecs_arg[grecs_grecs_count++] = grecs_grecs_tname[grecs_grecs_x];
-                grecs_grecs_size1 = grecs_grecs_size + grecs_grecs_tnamerr (YY_NULL, grecs_grecs_tname[grecs_grecs_x]);
-                if (! (grecs_grecs_size <= grecs_grecs_size1
-                       && grecs_grecs_size1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                grecs_grecs_size = grecs_grecs_size1;
+                {
+                  YYSIZE_T grecs_grecs_size1 = grecs_grecs_size + grecs_grecs_tnamerr (YY_NULL, grecs_grecs_tname[grecs_grecs_x]);
+                  if (! (grecs_grecs_size <= grecs_grecs_size1
+                         && grecs_grecs_size1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  grecs_grecs_size = grecs_grecs_size1;
+                }
               }
         }
     }
@@ -1103,10 +1150,12 @@ grecs_grecs_syntax_error (YYSIZE_T *grecs_grecs_msg_alloc, char **grecs_grecs_ms
 # undef YYCASE_
     }
 
-  grecs_grecs_size1 = grecs_grecs_size + grecs_grecs_strlen (grecs_grecs_format);
-  if (! (grecs_grecs_size <= grecs_grecs_size1 && grecs_grecs_size1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  grecs_grecs_size = grecs_grecs_size1;
+  {
+    YYSIZE_T grecs_grecs_size1 = grecs_grecs_size + grecs_grecs_strlen (grecs_grecs_format);
+    if (! (grecs_grecs_size <= grecs_grecs_size1 && grecs_grecs_size1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    grecs_grecs_size = grecs_grecs_size1;
+  }
 
   if (*grecs_grecs_msg_alloc < grecs_grecs_size)
     {
@@ -1168,35 +1217,35 @@ grecs_grecs_destruct (grecs_grecs_msg, grecs_grecs_type, grecs_grecs_valuep, gre
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int grecs_grecs_parse (void *YYPARSE_PARAM);
-#else
-int grecs_grecs_parse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int grecs_grecs_parse (void);
-#else
-int grecs_grecs_parse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int grecs_grecs_char;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE grecs_grecs_lval;
+YYSTYPE grecs_grecs_lval YY_INITIAL_VALUE(grecs_grecs_val_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE grecs_grecs_lloc;
+YYLTYPE grecs_grecs_lloc
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
+
 
 /* Number of syntax errors so far.  */
 int grecs_grecs_nerrs;
@@ -1263,7 +1312,7 @@ grecs_grecs_parse ()
   int grecs_grecs_n;
   int grecs_grecs_result;
   /* Lookahead token as an internal (translated) token number.  */
-  int grecs_grecs_token;
+  int grecs_grecs_token = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE grecs_grecs_val;
@@ -1282,10 +1331,9 @@ grecs_grecs_parse ()
      Keep to zero when no symbol should be popped.  */
   int grecs_grecs_len = 0;
 
-  grecs_grecs_token = 0;
-  grecs_grecs_ss = grecs_grecs_ssa;
-  grecs_grecs_vs = grecs_grecs_vsa;
-  grecs_grecs_ls = grecs_grecs_lsa;
+  grecs_grecs_ssp = grecs_grecs_ss = grecs_grecs_ssa;
+  grecs_grecs_vsp = grecs_grecs_vs = grecs_grecs_vsa;
+  grecs_grecs_lsp = grecs_grecs_ls = grecs_grecs_lsa;
   grecs_grecs_stacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1294,21 +1342,7 @@ grecs_grecs_parse ()
   grecs_grecs_errstatus = 0;
   grecs_grecs_nerrs = 0;
   grecs_grecs_char = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  grecs_grecs_ssp = grecs_grecs_ss;
-  grecs_grecs_vsp = grecs_grecs_vs;
-  grecs_grecs_lsp = grecs_grecs_ls;
-
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  grecs_grecs_lloc.first_line   = grecs_grecs_lloc.last_line   = 1;
-  grecs_grecs_lloc.first_column = grecs_grecs_lloc.last_column = 1;
-#endif
-
+  grecs_grecs_lsp[0] = grecs_grecs_lloc;
   goto grecs_grecs_setstate;
 
 /*------------------------------------------------------------.
@@ -1454,7 +1488,9 @@ grecs_grecs_backup:
   grecs_grecs_char = YYEMPTY;
 
   grecs_grecs_state = grecs_grecs_n;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_grecs_vsp = grecs_grecs_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++grecs_grecs_lsp = grecs_grecs_lloc;
   goto grecs_grecs_newstate;
 
@@ -1492,8 +1528,7 @@ grecs_grecs_reduce:
   switch (grecs_grecs_n)
     {
         case 2:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 58 "grecs-gram.y"
     {
 		  parse_tree = grecs_node_create(grecs_node_root, &(grecs_grecs_lsp[(1) - (1)]));
@@ -1503,8 +1538,7 @@ grecs_grecs_reduce:
     break;
 
   case 3:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 67 "grecs-gram.y"
     {
 		  (grecs_grecs_val.node) = NULL;
@@ -1512,8 +1546,7 @@ grecs_grecs_reduce:
     break;
 
   case 4:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 71 "grecs-gram.y"
     {
 		  (grecs_grecs_val.node) = (grecs_grecs_vsp[(1) - (1)].node_list).head;
@@ -1521,8 +1554,7 @@ grecs_grecs_reduce:
     break;
 
   case 5:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 77 "grecs-gram.y"
     {
 		  (grecs_grecs_val.node_list).head = (grecs_grecs_val.node_list).tail = (grecs_grecs_vsp[(1) - (1)].node);
@@ -1530,8 +1562,7 @@ grecs_grecs_reduce:
     break;
 
   case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 81 "grecs-gram.y"
     {
 		  grecs_node_bind((grecs_grecs_vsp[(1) - (2)].node_list).tail, (grecs_grecs_vsp[(2) - (2)].node), 0);
@@ -1539,8 +1570,7 @@ grecs_grecs_reduce:
     break;
 
   case 9:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 91 "grecs-gram.y"
     {
 		  (grecs_grecs_val.node) = grecs_node_create_points(grecs_node_stmt,
@@ -1552,8 +1582,7 @@ grecs_grecs_reduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 99 "grecs-gram.y"
     {
 		  (grecs_grecs_val.node) = grecs_node_create(grecs_node_stmt, &(grecs_grecs_lsp[(1) - (2)]));
@@ -1564,8 +1593,7 @@ grecs_grecs_reduce:
     break;
 
   case 11:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 108 "grecs-gram.y"
     {
 		  (grecs_grecs_val.node) = grecs_node_create_points(grecs_node_block,
@@ -1578,8 +1606,7 @@ grecs_grecs_reduce:
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 119 "grecs-gram.y"
     {
 		  (grecs_grecs_val.pvalue) = NULL;
@@ -1587,8 +1614,7 @@ grecs_grecs_reduce:
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 126 "grecs-gram.y"
     {
 		  size_t n;
@@ -1614,8 +1640,7 @@ grecs_grecs_reduce:
     break;
 
   case 15:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 150 "grecs-gram.y"
     {
 		  (grecs_grecs_val.list) = grecs_value_list_create();
@@ -1624,8 +1649,7 @@ grecs_grecs_reduce:
     break;
 
   case 16:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 155 "grecs-gram.y"
     {
 		  grecs_list_append((grecs_grecs_vsp[(1) - (2)].list), grecs_value_ptr_from_static(&(grecs_grecs_vsp[(2) - (2)].svalue)));
@@ -1633,8 +1657,7 @@ grecs_grecs_reduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 161 "grecs-gram.y"
     {
 		  (grecs_grecs_val.svalue).type = GRECS_TYPE_STRING;
@@ -1644,8 +1667,7 @@ grecs_grecs_reduce:
     break;
 
   case 18:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 167 "grecs-gram.y"
     {
 		  (grecs_grecs_val.svalue).type = GRECS_TYPE_LIST;
@@ -1655,8 +1677,7 @@ grecs_grecs_reduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 173 "grecs-gram.y"
     {
 		  (grecs_grecs_val.svalue).type = GRECS_TYPE_STRING;
@@ -1666,8 +1687,7 @@ grecs_grecs_reduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 186 "grecs-gram.y"
     {
 		  struct grecs_list_entry *ep;
@@ -1684,8 +1704,7 @@ grecs_grecs_reduce:
     break;
 
   case 24:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 201 "grecs-gram.y"
     {
 		  (grecs_grecs_val.list) = grecs_list_create();
@@ -1694,8 +1713,7 @@ grecs_grecs_reduce:
     break;
 
   case 25:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 206 "grecs-gram.y"
     {
 		  grecs_list_append((grecs_grecs_vsp[(1) - (2)].list), (grecs_grecs_vsp[(2) - (2)].string));
@@ -1704,8 +1722,7 @@ grecs_grecs_reduce:
     break;
 
   case 26:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 213 "grecs-gram.y"
     {
 		  (grecs_grecs_val.list) = NULL;
@@ -1713,8 +1730,7 @@ grecs_grecs_reduce:
     break;
 
   case 27:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 217 "grecs-gram.y"
     {
 		  (grecs_grecs_val.list) = (grecs_grecs_vsp[(2) - (3)].list);
@@ -1722,8 +1738,7 @@ grecs_grecs_reduce:
     break;
 
   case 28:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 221 "grecs-gram.y"
     {
 		  (grecs_grecs_val.list) = (grecs_grecs_vsp[(2) - (4)].list);
@@ -1731,8 +1746,7 @@ grecs_grecs_reduce:
     break;
 
   case 29:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 227 "grecs-gram.y"
     {
 		  (grecs_grecs_val.list) = grecs_value_list_create();
@@ -1741,8 +1755,7 @@ grecs_grecs_reduce:
     break;
 
   case 30:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 232 "grecs-gram.y"
     {
 		  grecs_list_append((grecs_grecs_vsp[(1) - (3)].list), grecs_value_ptr_from_static(&(grecs_grecs_vsp[(3) - (3)].svalue)));
@@ -1751,9 +1764,8 @@ grecs_grecs_reduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1757 "grecs-gram.c"
+/* Line 1792 of yacc.c  */
+#line 1769 "grecs-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter grecs_grecs_char, and that requires
@@ -1918,7 +1930,9 @@ grecs_grecs_errlab1:
       YY_STACK_PRINT (grecs_grecs_ss, grecs_grecs_ssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_grecs_vsp = grecs_grecs_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   grecs_grecs_error_range[2] = grecs_grecs_lloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -1989,8 +2003,7 @@ grecs_grecs_return:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 242 "grecs-gram.y"
 
 
@@ -2025,4 +2038,3 @@ grecs_grecs_parser(const char *name, int traceflags)
 
     
 
-
