@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,14 +58,11 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "meta1-gram.y"
 
 /* MeTA1 configuration parser for Grecs.
@@ -98,9 +95,8 @@ static struct grecs_node *parse_tree;
 extern int grecs_meta1__flex_debug;
 extern void grecs_meta1_set_in(FILE *);
 
-
-/* Line 268 of yacc.c  */
-#line 104 "meta1-gram.c"
+/* Line 371 of yacc.c  */
+#line 100 "meta1-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -110,11 +106,6 @@ extern void grecs_meta1_set_in(FILE *);
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -123,11 +114,17 @@ extern void grecs_meta1_set_in(FILE *);
 # define YYERROR_VERBOSE 1
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int grecs_meta1_debug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -145,12 +142,10 @@ extern void grecs_meta1_set_in(FILE *);
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 36 "meta1-gram.y"
 
 	char *string;
@@ -160,9 +155,8 @@ typedef union YYSTYPE
 	struct grecs_node *node;
 
 
-
-/* Line 295 of yacc.c  */
-#line 166 "meta1-gram.c"
+/* Line 387 of yacc.c  */
+#line 160 "meta1-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define grecs_meta1_stype YYSTYPE /* obsolescent; will be withdrawn */
@@ -182,12 +176,28 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
+extern YYSTYPE grecs_meta1_lval;
+extern YYLTYPE grecs_meta1_lloc;
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int grecs_meta1_parse (void *YYPARSE_PARAM);
+#else
+int grecs_meta1_parse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int grecs_meta1_parse (void);
+#else
+int grecs_meta1_parse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 191 "meta1-gram.c"
+/* Line 390 of yacc.c  */
+#line 201 "meta1-gram.c"
 
 #ifdef short
 # undef short
@@ -240,24 +250,24 @@ typedef short int grecs_meta1_type_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -489,7 +499,7 @@ static const grecs_meta1_type_uint8 grecs_meta1_rline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const grecs_meta1_tname[] =
@@ -573,10 +583,10 @@ static const grecs_meta1_type_uint8 grecs_meta1_table[] =
       26,    33,    27,    12
 };
 
-#define grecs_meta1_pact_value_is_default(grecs_meta1_state) \
-  ((grecs_meta1_state) == (-15))
+#define grecs_meta1_pact_value_is_default(Yystate) \
+  (!!((Yystate) == (-15)))
 
-#define grecs_meta1_table_value_is_error(grecs_meta1_table_value) \
+#define grecs_meta1_table_value_is_error(Yytable_value) \
   YYID (0)
 
 static const grecs_meta1_type_uint8 grecs_meta1_check[] =
@@ -640,7 +650,7 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
@@ -649,27 +659,28 @@ while (YYID (0))
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -677,10 +688,46 @@ while (YYID (0))
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+grecs_meta1__location_print_ (FILE *grecs_meta1_o, YYLTYPE const * const grecs_meta1_locp)
+#else
+static unsigned
+grecs_meta1__location_print_ (grecs_meta1_o, grecs_meta1_locp)
+    FILE *grecs_meta1_o;
+    YYLTYPE const * const grecs_meta1_locp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != grecs_meta1_locp->last_column ? grecs_meta1_locp->last_column - 1 : 0;
+  if (0 <= grecs_meta1_locp->first_line)
+    {
+      res += fprintf (grecs_meta1_o, "%d", grecs_meta1_locp->first_line);
+      if (0 <= grecs_meta1_locp->first_column)
+        res += fprintf (grecs_meta1_o, ".%d", grecs_meta1_locp->first_column);
+    }
+  if (0 <= grecs_meta1_locp->last_line)
+    {
+      if (grecs_meta1_locp->first_line < grecs_meta1_locp->last_line)
+        {
+          res += fprintf (grecs_meta1_o, "-%d", grecs_meta1_locp->last_line);
+          if (0 <= end_col)
+            res += fprintf (grecs_meta1_o, ".%d", end_col);
+        }
+      else if (0 <= end_col && grecs_meta1_locp->first_column < end_col)
+        res += fprintf (grecs_meta1_o, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  grecs_meta1__location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -688,7 +735,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `grecs_meta1_lex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX grecs_meta1_lex (YYLEX_PARAM)
 #else
@@ -753,7 +799,7 @@ grecs_meta1__symbol_value_print (grecs_meta1_output, grecs_meta1_type, grecs_met
   switch (grecs_meta1_type)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -999,7 +1045,6 @@ grecs_meta1_syntax_error (YYSIZE_T *grecs_meta1_msg_alloc, char **grecs_meta1_ms
 {
   YYSIZE_T grecs_meta1_size0 = grecs_meta1_tnamerr (YY_NULL, grecs_meta1_tname[grecs_meta1_token]);
   YYSIZE_T grecs_meta1_size = grecs_meta1_size0;
-  YYSIZE_T grecs_meta1_size1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *grecs_meta1_format = YY_NULL;
@@ -1062,11 +1107,13 @@ grecs_meta1_syntax_error (YYSIZE_T *grecs_meta1_msg_alloc, char **grecs_meta1_ms
                     break;
                   }
                 grecs_meta1_arg[grecs_meta1_count++] = grecs_meta1_tname[grecs_meta1_x];
-                grecs_meta1_size1 = grecs_meta1_size + grecs_meta1_tnamerr (YY_NULL, grecs_meta1_tname[grecs_meta1_x]);
-                if (! (grecs_meta1_size <= grecs_meta1_size1
-                       && grecs_meta1_size1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                grecs_meta1_size = grecs_meta1_size1;
+                {
+                  YYSIZE_T grecs_meta1_size1 = grecs_meta1_size + grecs_meta1_tnamerr (YY_NULL, grecs_meta1_tname[grecs_meta1_x]);
+                  if (! (grecs_meta1_size <= grecs_meta1_size1
+                         && grecs_meta1_size1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  grecs_meta1_size = grecs_meta1_size1;
+                }
               }
         }
     }
@@ -1086,10 +1133,12 @@ grecs_meta1_syntax_error (YYSIZE_T *grecs_meta1_msg_alloc, char **grecs_meta1_ms
 # undef YYCASE_
     }
 
-  grecs_meta1_size1 = grecs_meta1_size + grecs_meta1_strlen (grecs_meta1_format);
-  if (! (grecs_meta1_size <= grecs_meta1_size1 && grecs_meta1_size1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  grecs_meta1_size = grecs_meta1_size1;
+  {
+    YYSIZE_T grecs_meta1_size1 = grecs_meta1_size + grecs_meta1_strlen (grecs_meta1_format);
+    if (! (grecs_meta1_size <= grecs_meta1_size1 && grecs_meta1_size1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    grecs_meta1_size = grecs_meta1_size1;
+  }
 
   if (*grecs_meta1_msg_alloc < grecs_meta1_size)
     {
@@ -1151,35 +1200,35 @@ grecs_meta1_destruct (grecs_meta1_msg, grecs_meta1_type, grecs_meta1_valuep, gre
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int grecs_meta1_parse (void *YYPARSE_PARAM);
-#else
-int grecs_meta1_parse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int grecs_meta1_parse (void);
-#else
-int grecs_meta1_parse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int grecs_meta1_char;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE grecs_meta1_lval;
+YYSTYPE grecs_meta1_lval YY_INITIAL_VALUE(grecs_meta1_val_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE grecs_meta1_lloc;
+YYLTYPE grecs_meta1_lloc
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
+
 
 /* Number of syntax errors so far.  */
 int grecs_meta1_nerrs;
@@ -1246,7 +1295,7 @@ grecs_meta1_parse ()
   int grecs_meta1_n;
   int grecs_meta1_result;
   /* Lookahead token as an internal (translated) token number.  */
-  int grecs_meta1_token;
+  int grecs_meta1_token = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE grecs_meta1_val;
@@ -1265,10 +1314,9 @@ grecs_meta1_parse ()
      Keep to zero when no symbol should be popped.  */
   int grecs_meta1_len = 0;
 
-  grecs_meta1_token = 0;
-  grecs_meta1_ss = grecs_meta1_ssa;
-  grecs_meta1_vs = grecs_meta1_vsa;
-  grecs_meta1_ls = grecs_meta1_lsa;
+  grecs_meta1_ssp = grecs_meta1_ss = grecs_meta1_ssa;
+  grecs_meta1_vsp = grecs_meta1_vs = grecs_meta1_vsa;
+  grecs_meta1_lsp = grecs_meta1_ls = grecs_meta1_lsa;
   grecs_meta1_stacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1277,21 +1325,7 @@ grecs_meta1_parse ()
   grecs_meta1_errstatus = 0;
   grecs_meta1_nerrs = 0;
   grecs_meta1_char = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  grecs_meta1_ssp = grecs_meta1_ss;
-  grecs_meta1_vsp = grecs_meta1_vs;
-  grecs_meta1_lsp = grecs_meta1_ls;
-
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  grecs_meta1_lloc.first_line   = grecs_meta1_lloc.last_line   = 1;
-  grecs_meta1_lloc.first_column = grecs_meta1_lloc.last_column = 1;
-#endif
-
+  grecs_meta1_lsp[0] = grecs_meta1_lloc;
   goto grecs_meta1_setstate;
 
 /*------------------------------------------------------------.
@@ -1437,7 +1471,9 @@ grecs_meta1_backup:
   grecs_meta1_char = YYEMPTY;
 
   grecs_meta1_state = grecs_meta1_n;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_meta1_vsp = grecs_meta1_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++grecs_meta1_lsp = grecs_meta1_lloc;
   goto grecs_meta1_newstate;
 
@@ -1475,8 +1511,7 @@ grecs_meta1_reduce:
   switch (grecs_meta1_n)
     {
         case 2:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 54 "meta1-gram.y"
     {
 		  parse_tree = grecs_node_create(grecs_node_root, &(grecs_meta1_lsp[(1) - (1)]));
@@ -1486,8 +1521,7 @@ grecs_meta1_reduce:
     break;
 
   case 3:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 63 "meta1-gram.y"
     {
 		  (grecs_meta1_val.node) = NULL;
@@ -1495,8 +1529,7 @@ grecs_meta1_reduce:
     break;
 
   case 4:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 67 "meta1-gram.y"
     {
 		  (grecs_meta1_val.node) = (grecs_meta1_vsp[(1) - (1)].node_list).head;
@@ -1504,8 +1537,7 @@ grecs_meta1_reduce:
     break;
 
   case 5:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 73 "meta1-gram.y"
     {
 		  (grecs_meta1_val.node_list).head = (grecs_meta1_val.node_list).tail = (grecs_meta1_vsp[(1) - (1)].node);
@@ -1513,8 +1545,7 @@ grecs_meta1_reduce:
     break;
 
   case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 77 "meta1-gram.y"
     {
 		  grecs_node_bind((grecs_meta1_vsp[(1) - (2)].node_list).tail, (grecs_meta1_vsp[(2) - (2)].node), 0);
@@ -1522,8 +1553,7 @@ grecs_meta1_reduce:
     break;
 
   case 9:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 87 "meta1-gram.y"
     {
 		  (grecs_meta1_val.node) = grecs_node_create_points(grecs_node_stmt,
@@ -1535,8 +1565,7 @@ grecs_meta1_reduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 97 "meta1-gram.y"
     {
 		  (grecs_meta1_val.node) = grecs_node_create_points(grecs_node_block,
@@ -1549,8 +1578,7 @@ grecs_meta1_reduce:
     break;
 
   case 11:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 108 "meta1-gram.y"
     {
 		  (grecs_meta1_val.pvalue) = NULL;
@@ -1558,8 +1586,7 @@ grecs_meta1_reduce:
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 112 "meta1-gram.y"
     {
 		  (grecs_meta1_val.pvalue) = grecs_malloc(sizeof((grecs_meta1_val.pvalue)[0]));
@@ -1569,8 +1596,7 @@ grecs_meta1_reduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 120 "meta1-gram.y"
     {
 		  (grecs_meta1_val.pvalue) = grecs_malloc(sizeof((grecs_meta1_val.pvalue)[0]));
@@ -1581,8 +1607,7 @@ grecs_meta1_reduce:
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 127 "meta1-gram.y"
     {
 		  (grecs_meta1_val.pvalue) = grecs_malloc(sizeof((grecs_meta1_val.pvalue)[0]));
@@ -1593,8 +1618,7 @@ grecs_meta1_reduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 140 "meta1-gram.y"
     {
 		  struct grecs_list_entry *ep;
@@ -1611,8 +1635,7 @@ grecs_meta1_reduce:
     break;
 
   case 18:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 154 "meta1-gram.y"
     {
 		  (grecs_meta1_val.list) = grecs_list_create();
@@ -1621,8 +1644,7 @@ grecs_meta1_reduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 159 "meta1-gram.y"
     {
 		  grecs_list_append((grecs_meta1_vsp[(1) - (2)].list), (grecs_meta1_vsp[(2) - (2)].string));
@@ -1631,8 +1653,7 @@ grecs_meta1_reduce:
     break;
 
   case 20:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 166 "meta1-gram.y"
     {
 		  (grecs_meta1_val.list) = (grecs_meta1_vsp[(2) - (3)].list);
@@ -1640,8 +1661,7 @@ grecs_meta1_reduce:
     break;
 
   case 21:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 170 "meta1-gram.y"
     {
 		  (grecs_meta1_val.list) = (grecs_meta1_vsp[(2) - (4)].list);
@@ -1649,8 +1669,7 @@ grecs_meta1_reduce:
     break;
 
   case 22:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 176 "meta1-gram.y"
     {
 		  (grecs_meta1_val.list) = grecs_value_list_create();
@@ -1659,8 +1678,7 @@ grecs_meta1_reduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 181 "meta1-gram.y"
     {
 		  grecs_list_append((grecs_meta1_vsp[(1) - (3)].list), (grecs_meta1_vsp[(3) - (3)].pvalue));
@@ -1669,9 +1687,8 @@ grecs_meta1_reduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1675 "meta1-gram.c"
+/* Line 1792 of yacc.c  */
+#line 1692 "meta1-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter grecs_meta1_char, and that requires
@@ -1836,7 +1853,9 @@ grecs_meta1_errlab1:
       YY_STACK_PRINT (grecs_meta1_ss, grecs_meta1_ssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_meta1_vsp = grecs_meta1_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   grecs_meta1_error_range[2] = grecs_meta1_lloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -1907,8 +1926,7 @@ grecs_meta1_return:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 191 "meta1-gram.y"
 
 int
@@ -1946,4 +1964,3 @@ grecs_meta1_parser(const char *name, int traceflags)
 	return parse_tree;
 }
 	
-
