@@ -148,85 +148,50 @@ static struct grecs_keyword syslog_kw[] = {
 
 struct eventconf {
 	struct grecs_list *pathlist;
-        event_mask eventmask;
-	struct grecs_list *fnames;
-	char *command;
-	uid_t uid;           /* Run as this user (unless 0) */
-	gid_t *gidv;         /* Run with these groups' privileges */
-	size_t gidc;         /* Number of elements in gidv */
-	unsigned timeout;
-	int flags;
-	char **env;
+	event_mask ev_mask;
+	filpatlist_t fpat;
+	struct prog_handler prog_handler;
 };
 
 static struct eventconf eventconf;
 
 static void
-envfree(char **env)
-{
-	int i;
-
-	if (!env)
-		return;
-	for (i = 0; env[i]; i++)
-		free(env[i]);
-	free(env);
-}
-
-static void
-eventconf_init()
+eventconf_init(void)
 {
 	memset(&eventconf, 0, sizeof eventconf);
-	eventconf.timeout = DEFAULT_TIMEOUT;
+	eventconf.prog_handler.timeout = DEFAULT_TIMEOUT;
 }
 
 static void
-eventconf_free()
+eventconf_free(void)
 {
 	grecs_list_free(eventconf.pathlist);
-	grecs_list_free(eventconf.fnames);
-	free(eventconf.command);
-	free(eventconf.gidv);
-	envfree(eventconf.env);
+	prog_handler_free(&eventconf.prog_handler);
+	filpatlist_destroy(&eventconf.fpat);
 }
 
 void
 eventconf_flush(grecs_locus_t *loc)
 {
 	struct grecs_list_entry *ep;
-	
+	struct handler *hp = prog_handler_alloc(eventconf.ev_mask,
+						eventconf.fpat,
+						&eventconf.prog_handler);
+
 	for (ep = eventconf.pathlist->head; ep; ep = ep->next) {
 		struct pathent *pe = ep->data;
-		struct dirwatcher *dwp;
-		struct handler *hp;
+		struct watchpoint *wpt;
 		int isnew;
 		
-		dwp = dirwatcher_install(pe->path, &isnew);
-		if (!dwp)
+		wpt = watchpoint_install(pe->path, &isnew);
+		if (!wpt)
 			abort();
-		if (!isnew && dwp->depth != pe->depth)
+		if (!isnew && wpt->depth != pe->depth)
 			grecs_error(loc, 0,
 				    _("%s: recursion depth does not match previous definition"),
 				    pe->path);
-		dwp->depth = pe->depth;
-		
-		hp = emalloc(sizeof(*hp));
-		hp->next = NULL;
-		hp->ev_mask = eventconf.eventmask;
-		hp->fnames = eventconf.fnames;
-		hp->flags = eventconf.flags;
-		hp->timeout = eventconf.timeout;
-		hp->prog = eventconf.command;
-		hp->uid = eventconf.uid;
-		hp->gidc = eventconf.gidc;
-		hp->gidv = eventconf.gidv;
-		hp->env = eventconf.env;
-		
-		if (dwp->handler_tail)
-			dwp->handler_tail->next = hp;
-		else
-			dwp->handler_list = hp;
-		dwp->handler_tail = hp;
+		wpt->depth = pe->depth;
+		handler_list_append(wpt->handler_list, hp);
 	}
 	grecs_list_free(eventconf.pathlist);
 	eventconf_init();
@@ -247,13 +212,13 @@ cb_watcher(enum grecs_callback_command cmd, grecs_node_t *node,
 			grecs_error(&node->locus, 0, _("no paths configured"));
 			++err;
 		}
-		if (!eventconf.command) {
+		if (!eventconf.prog_handler.command) {
 			grecs_error(&node->locus, 0,
 				    _("no command configured"));
 			++err;
 		}
-		if (evtnullp(&eventconf.eventmask))
-			evtsetall(&eventconf.eventmask);
+		if (evtnullp(&eventconf.ev_mask))
+			evtsetall(&eventconf.ev_mask);
 		if (err == 0)
 			eventconf_flush(&node->locus);
 		else
@@ -498,8 +463,9 @@ cb_user(enum grecs_callback_command cmd, grecs_node_t *node,
 	} else
 		gid = pw->pw_gid;
 
-	eventconf.uid = pw->pw_uid;
-	get_user_groups(uv->v.string, gid, &eventconf.gidc, &eventconf.gidv);
+	eventconf.prog_handler.uid = pw->pw_uid;
+	get_user_groups(uv->v.string, gid,
+			&eventconf.prog_handler.gidc, &eventconf.prog_handler.gidv);
 	
 	return 0;
 }
@@ -522,15 +488,15 @@ cb_option(enum grecs_callback_command cmd, grecs_node_t *node,
 					    GRECS_TYPE_STRING))
 			return 1;
 		if (strcmp(vp->v.string, "nowait") == 0)
-			eventconf.flags |= HF_NOWAIT;
+			eventconf.prog_handler.flags |= HF_NOWAIT;
 		else if (strcmp(vp->v.string, "wait") == 0)
-			eventconf.flags &= ~HF_NOWAIT;
+			eventconf.prog_handler.flags &= ~HF_NOWAIT;
 		else if (strcmp(vp->v.string, "stdout") == 0)
-			eventconf.flags |= HF_STDOUT;
+			eventconf.prog_handler.flags |= HF_STDOUT;
 		else if (strcmp(vp->v.string, "stderr") == 0)
-			eventconf.flags |= HF_STDERR;
+			eventconf.prog_handler.flags |= HF_STDERR;
 		else if (strcmp(vp->v.string, "shell") == 0)
-			eventconf.flags |= HF_SHELL;
+			eventconf.prog_handler.flags |= HF_SHELL;
 		else 
 			grecs_error(&vp->locus, 0, _("unrecognized option"));
 	}
@@ -544,7 +510,7 @@ cb_environ(enum grecs_callback_command cmd, grecs_node_t *node,
         grecs_locus_t *locus = &node->locus;
 	grecs_value_t *val = node->v.value;
 	struct grecs_list_entry *ep;
-	int i;
+	int i, j;
 	
 	ASSERT_SCALAR(cmd, locus);
 	switch (val->type) {
@@ -552,103 +518,44 @@ cb_environ(enum grecs_callback_command cmd, grecs_node_t *node,
 		if (assert_grecs_value_type(&val->locus, val,
 					    GRECS_TYPE_STRING))
 			return 1;
-		eventconf.env = ecalloc(2, sizeof(eventconf.env[0]));
-		eventconf.env[0] = estrdup(val->v.string);
-		eventconf.env[1] = NULL;
+		i = prog_handler_envrealloc(&eventconf.prog_handler, 1);
+		eventconf.prog_handler.env[i] = estrdup(val->v.string);
+		eventconf.prog_handler.env[i+1] = NULL;
 		break;
 		
 	case GRECS_TYPE_ARRAY:
-		eventconf.env = ecalloc(val->v.arg.c + 1,
-					sizeof(eventconf.env[0]));
-		for (i = 0; i < val->v.arg.c; i++) {
+		j = prog_handler_envrealloc(&eventconf.prog_handler, val->v.arg.c);
+		for (i = 0; i < val->v.arg.c; i++, j++) {
 			if (assert_grecs_value_type(&val->v.arg.v[i]->locus,
 						    val->v.arg.v[i],
 						    GRECS_TYPE_STRING))
 				return 1;
-			eventconf.env[i] = estrdup(val->v.arg.v[i]->v.string);
+			eventconf.prog_handler.env[j] = estrdup(val->v.arg.v[i]->v.string);
 		}
-		eventconf.env[i] = NULL;
+		eventconf.prog_handler.env[j] = NULL;
 		break;
 
 	case GRECS_TYPE_LIST:
-		eventconf.env = ecalloc(val->v.list->count + 1,
-					sizeof(eventconf.env[0]));
-		for (i = 0, ep = val->v.list->head; ep; ep = ep->next, i++) {
+		j = prog_handler_envrealloc(&eventconf.prog_handler,
+					    val->v.list->count);
+		for (ep = val->v.list->head; ep; ep = ep->next, j++) {
 			grecs_value_t *vp = ep->data;
 			if (assert_grecs_value_type(&vp->locus, vp,
 						    GRECS_TYPE_STRING))
 				return 1;
-			eventconf.env[i] = estrdup(vp->v.string);
+			eventconf.prog_handler.env[j] = estrdup(vp->v.string);
 		}
-		eventconf.env[i] = NULL;
+		eventconf.prog_handler.env[j] = NULL;
 	}
 	return 0;
 }		
 
 static int
-file_name_pattern(struct grecs_list *lp, grecs_value_t *val)
+file_name_pattern(filpatlist_t *fptr, grecs_value_t *val)
 {
-	char *arg;
-	int rc;
-	int flags = REG_EXTENDED|REG_NOSUB;
-	struct filename_pattern *pat;
-	
 	if (assert_grecs_value_type(&val->locus, val, GRECS_TYPE_STRING))
 		return 1;
-	arg = val->v.string;
-
-	pat = emalloc(sizeof(*pat));
-	if (*arg == '!') {
-		pat->neg = 1;
-		++arg;
-	} else
-		pat->neg = 0;
-	if (arg[0] == '/') {
-		char *q, *p;
-
-		pat->type = PAT_REGEX;
-		
-		p = strchr(arg+1, '/');
-		if (!p) {
-			grecs_error(&val->locus, 0, _("unterminated regexp"));
-			free(pat);
-			return 1;
-		}
-		for (q = p + 1; *q; q++) {
-			switch (*q) {
-			case 'b':
-				flags &= ~REG_EXTENDED;
-				break;
-			case 'i':
-				flags |= REG_ICASE;
-				break;
-			default:
-				grecs_error(&val->locus, 0,
-					    _("unrecognized flag: %c"), *q);
-				free(pat);
-				return 1;
-			}
-		}
-		
-		*p = 0;
-		rc = regcomp(&pat->v.re, arg + 1, flags);
-		*p = '/';
-
-		if (rc) {
-			char errbuf[128];
-			regerror(rc, &pat->v.re, errbuf, sizeof(errbuf));
-			grecs_error(&val->locus, 0, "%s", errbuf);
-			filename_pattern_free(pat);
-			return 1;
-		}
-	} else {
-		pat->type = PAT_GLOB;
-		pat->v.glob = estrdup(arg);
-	}
-
-	grecs_list_append(lp, pat);
-
-	return 0;
+	return filpatlist_add(fptr, val->v.string, &val->locus);
 }
 
 static int
@@ -656,33 +563,26 @@ cb_file_pattern(enum grecs_callback_command cmd, grecs_node_t *node,
 		void *varptr, void *cb_data)
 {
 	grecs_value_t *val = node->v.value;
+	filpatlist_t *fpat = varptr;
 	struct grecs_list_entry *ep;
-	struct grecs_list *lp, **lpp = varptr;
 	int i;
 	
 	ASSERT_SCALAR(cmd, &node->locus);
 
-	if (!*lpp) {
-		lp = grecs_list_create();
-		lp->free_entry = filename_pattern_free;
-		*lpp = lp;
-	} else
-		lp = *lpp;
-	
 	switch (val->type) {
 	case GRECS_TYPE_STRING:
-		file_name_pattern(lp, val);
+		file_name_pattern(fpat, val);
 		break;
 
 	case GRECS_TYPE_ARRAY:
 		for (i = 0; i < val->v.arg.c; i++)
-			if (file_name_pattern(lp, val->v.arg.v[i]))
+			if (file_name_pattern(fpat, val->v.arg.v[i]))
 				break;
 		break;
 
 	case GRECS_TYPE_LIST:
 		for (ep = val->v.list->head; ep; ep = ep->next)
-			if (file_name_pattern(lp,
+			if (file_name_pattern(fpat,
 					      (grecs_value_t *) ep->data))
 				break;
 		break;
@@ -696,18 +596,18 @@ static struct grecs_keyword watcher_kw[] = {
 	  grecs_type_string, GRECS_DFLT, &eventconf.pathlist, 0,
 	  cb_path },
 	{ "event", NULL, N_("Events to watch for"),
-	  grecs_type_string, GRECS_LIST, &eventconf.eventmask, 0,
+	  grecs_type_string, GRECS_LIST, &eventconf.ev_mask, 0,
 	  cb_eventlist },
 	{ "file", N_("regexp"), N_("Files to watch for"),
-	  grecs_type_string, GRECS_LIST, &eventconf.fnames, 0,
+	  grecs_type_string, GRECS_LIST, &eventconf.fpat, 0,
 	  cb_file_pattern },
 	{ "command", NULL, N_("Command to execute on event"),
-	  grecs_type_string, GRECS_DFLT, &eventconf.command },
+	  grecs_type_string, GRECS_DFLT, &eventconf.prog_handler.command },
 	{ "user", N_("name"), N_("Run command as this user"),
 	  grecs_type_string, GRECS_DFLT, NULL, 0,
 	  cb_user },
 	{ "timeout", N_("seconds"), N_("Timeout for the command"),
-	  grecs_type_uint, GRECS_DFLT, &eventconf.timeout },
+	  grecs_type_uint, GRECS_DFLT, &eventconf.prog_handler.timeout },
 	{ "option", NULL, N_("List of additional options"),
 	  grecs_type_string, GRECS_LIST, NULL, 0,
 	  cb_option },
@@ -757,6 +657,7 @@ config_parse(char const *conffile)
 {
 	struct grecs_node *tree;
 
+	grecs_parser_options = GRECS_OPTION_QUOTED_STRING_CONCAT;
 	tree = grecs_parse(conffile);
 	if (!tree)
 		exit(1);
