@@ -186,6 +186,8 @@ mkfilename(const char *dir, const char *file)
 	size_t fillen = strlen(file);
 	size_t len;
 
+	if (!file || file[0] == 0)
+		return strdup(dir);
 	while (dirlen > 0 && dir[dirlen-1] == '/')
 		dirlen--;
 
@@ -362,7 +364,7 @@ setuser(const char *user)
 }
 
 void
-ev_log(int flags, struct dirwatcher *dp)
+ev_log(int flags, struct watchpoint *dp)
 {
 	int i;
 	char *p;
@@ -536,8 +538,11 @@ main(int argc, char **argv)
 	while (!stop && sysev_select() == 0) {
 		process_timeouts();
 		process_cleanup(0);
+		watchpoint_gc();
 	}
 
+	shutdown_watchers();
+
 	diag(LOG_INFO, _("%s %s stopped"), program_name, VERSION);
 
 	if (pidfile)
