@@ -24,7 +24,8 @@
 #include <unistd.h>
 #include <signal.h>
 #include <regex.h>
-
+#include <grecs/list.h>
+#include <grecs/symtab.h>
 #include "gettext.h"
 
 #define _(s) gettext(s)
@@ -37,10 +38,10 @@
 #define GENEV_DELETE  0x08
 
 /* Handler flags. */
-#define HF_NOWAIT 0x01       /* Don't wait for termination */
-#define HF_STDOUT 0x02       /* Capture stdout */
-#define HF_STDERR 0x04       /* Capture stderr */
-#define HF_SHELL  0x08       /* Call program via /bin/sh -c */ 
+#define HF_NOWAIT  0x01   /* Don't wait for termination */
+#define HF_STDOUT  0x02   /* Capture stdout */
+#define HF_STDERR  0x04   /* Capture stderr */
+#define HF_SHELL   0x08   /* Call program via /bin/sh -c */ 
 
 #ifndef DEFAULT_TIMEOUT
 # define DEFAULT_TIMEOUT 5
@@ -57,11 +58,14 @@ struct transtab {
 	int tok;
 };
 
-#define PAT_GLOB  0
-#define PAT_REGEX 1
+enum pattern_type {
+	PAT_EXACT,
+	PAT_GLOB,
+	PAT_REGEX
+};
 
 struct filename_pattern {
-	int type;
+	enum pattern_type type;
 	int neg;
 	union {
 		regex_t re;
@@ -69,29 +73,40 @@ struct filename_pattern {
 	} v;
 };
 
+typedef struct filpatlist *filpatlist_t;
+
+struct watchpoint;
+
+typedef int (*event_handler_fn) (struct watchpoint *wp,
+				 event_mask *event,
+				 const char *dir,
+				 const char *file,
+				 void *data);
+typedef void (*handler_free_fn) (void *data);
+
 /* Handler structure */
 struct handler {
-	struct handler *next;
-	event_mask ev_mask;  /* Event mask */
-	struct grecs_list *fnames;  /* File name patterns */
-	int flags;           /* Handler flags */
-	const char *prog;    /* Handler program (with eventual arguments) */
-	uid_t uid;           /* Run as this user (unless 0) */
-	gid_t *gidv;         /* Run with these groups' privileges */
-	size_t gidc;         /* Number of elements in gidv */
-	unsigned timeout;    /* Handler timeout */
-	char **env;          /* Environment */
+	size_t refcnt;        /* Reference counter */
+	event_mask ev_mask;   /* Event mask */
+	filpatlist_t fnames;  /* File name patterns */
+	event_handler_fn run;
+	handler_free_fn free;
+	void *data;
 };
 
-/* A directory watcher is described by the following structure */
-struct dirwatcher {
-	int refcnt;
+typedef struct handler_list *handler_list_t;
+typedef struct handler_iterator *handler_iterator_t;
+
+/* Watchpoint links the directory being monitored and a list of
+   handlers for various events: */
+struct watchpoint {
+	size_t refcnt;
 	int wd;                              /* Watch descriptor */
-	struct dirwatcher *parent;           /* Points to the parent watcher.
+	struct watchpoint *parent;           /* Points to the parent watcher.
 					        NULL for top-level watchers */
 	char *dirname;                       /* Pathname being watched */
-	struct handler *handler_list;        /* List of handlers */
-	struct handler *handler_tail;        /* Tail of the handler list */
+	int isdir;                           /* Is it directory */
+	handler_list_t handler_list;         /* List of handlers */
 	int depth;                           /* Recursion depth */
 	char *split_p;                       /* Points to the deleted directory
 						separator in dirname (see
@@ -105,8 +120,26 @@ struct dirwatcher {
 
 #define __cat2__(a,b) a ## b
 #define handler_matches_event(h,m,f,n)		\
-	(((h)->ev_mask.__cat2__(m,_mask) & (f)) && \
-	 filename_pattern_match((h)->fnames, n) == 0)
+	(((h)->ev_mask.__cat2__(m,_mask) & (f)) &&	\
+	 filpatlist_match((h)->fnames, n) == 0)
+
+struct handler *handler_alloc(event_mask ev_mask);
+void handler_free(struct handler *hp);
+
+struct prog_handler {
+	int flags;     /* Handler flags */
+	char *command; /* Handler command (with eventual arguments) */
+	uid_t uid;     /* Run as this user (unless 0) */
+	gid_t *gidv;   /* Run with these groups' privileges */
+	size_t gidc;   /* Number of elements in gidv */
+	unsigned timeout; /* Handler timeout */
+	char **env;    /* Environment */
+};
+
+struct handler *prog_handler_alloc(event_mask ev_mask, filpatlist_t fpat,
+				   struct prog_handler *p);
+void prog_handler_free(struct prog_handler *);
+size_t prog_handler_envrealloc(struct prog_handler *hp, size_t count);
 
 
 extern int foreground;
@@ -140,10 +173,10 @@ void debugprt(const char *fmt, ...);
 void signal_setup(void (*sf) (int));
 int detach(void (*)(void));
 
-int sysev_filemask(struct dirwatcher *dp);
+int sysev_filemask(struct watchpoint *dp);
 void sysev_init(void);
-int sysev_add_watch(struct dirwatcher *dwp, event_mask mask);
-void sysev_rm_watch(struct dirwatcher *dwp);
+int sysev_add_watch(struct watchpoint *dwp, event_mask mask);
+void sysev_rm_watch(struct watchpoint *dwp);
 int sysev_select(void);
 int sysev_name_to_code(const char *name);
 const char *sysev_code_to_name(int code);
@@ -165,34 +198,6 @@ int trans_strtotok(struct transtab *tab, const char *str, int *ret);
 char *trans_toktostr(struct transtab *tab, int tok);
 char *trans_tokfirst(struct transtab *tab, int tok, int *next);
 char *trans_toknext(struct transtab *tab, int tok, int *next);
-
-
-struct hashtab;
-struct hashent {
-	int used;
-};
-int hashtab_replace(struct hashtab *st, void *ent, void **old_ent);
-const char *hashtab_strerror(int rc);
-int hashtab_remove(struct hashtab *st, void *elt);
-int hashtab_get_index(unsigned *idx, struct hashtab *st, void *key,
-		      int *install);
-void *hashtab_lookup_or_install(struct hashtab *st, void *key, int *install);
-void hashtab_clear(struct hashtab *st);
-struct hashtab *hashtab_create(size_t elsize, 
-			       unsigned (*hash_fun)(void *, unsigned long),
-			       int (*cmp_fun)(const void *, const void *),
-			       int (*copy_fun)(void *, void *),
-			       void *(*alloc_fun)(size_t),
-			       void (*free_fun)(void *));
-void hashtab_free(struct hashtab *st);
-size_t hashtab_count_entries(struct hashtab *st);
-
-typedef int (*hashtab_enumerator_t) (struct hashent *, void *);
-int hashtab_foreach(struct hashtab *st, hashtab_enumerator_t fun,
-		    void *data);
-size_t hashtab_count(struct hashtab *st);
-
-unsigned hash_string(const char *name, unsigned long hashsize);
 
 struct pathent {
 	long depth;
@@ -207,27 +212,61 @@ void config_parse(const char *file);
 int get_facility(const char *arg);
 int get_priority(const char *arg);
 
+int  watchpoint_init(struct watchpoint *dwp);
+void watchpoint_ref(struct watchpoint *dw);
+void watchpoint_unref(struct watchpoint *dw);
+void watchpoint_gc(void);
+
+int watchpoint_pattern_match(struct watchpoint *dwp, const char *file_name);
+
+void watchpoint_run_handlers(struct watchpoint *wp, int evflags,
+			      const char *dirname, const char *filename);
+
+
 void setup_watchers(void);
-struct dirwatcher *dirwatcher_lookup(const char *dirname);
-struct dirwatcher *dirwatcher_lookup_wd(int wd);
+void shutdown_watchers(void);
+
+struct watchpoint *watchpoint_lookup(const char *dirname);
 int check_new_watcher(const char *dir, const char *name);
-struct dirwatcher *dirwatcher_install(const char *path, int *pnew);
-void dirwatcher_destroy(struct dirwatcher *dwp);
-int watch_pathname(struct dirwatcher *parent, const char *dirname, int isdir, int notify);
+struct watchpoint *watchpoint_install(const char *path, int *pnew);
+struct watchpoint *watchpoint_install_ptr(struct watchpoint *dw);
+void watchpoint_suspend(struct watchpoint *dwp);
+void watchpoint_destroy(struct watchpoint *dwp);
+int watchpoint_install_sentinel(struct watchpoint *dwp);
 
-char *split_pathname(struct dirwatcher *dp, char **dirname);
-void unsplit_pathname(struct dirwatcher *dp);
+int watch_pathname(struct watchpoint *parent, const char *dirname, int isdir, int notify);
 
-void ev_log(int flags, struct dirwatcher *dp);
-void deliver_ev_create(struct dirwatcher *dp, const char *name);
-int subwatcher_create(struct dirwatcher *parent, const char *dirname,
-		      int isdir, int notify);
+char *split_pathname(struct watchpoint *dp, char **dirname);
+void unsplit_pathname(struct watchpoint *dp);
+
+void ev_log(int flags, struct watchpoint *dp);
+void deliver_ev_create(struct watchpoint *dp,
+		       const char *dirname, const char *filename);
+int subwatcher_create(struct watchpoint *parent, const char *dirname,
+		      int notify);
+
+struct handler *handler_itr_first(struct watchpoint *dp,
+				       handler_iterator_t *itr);
+struct handler *handler_itr_next(handler_iterator_t *itr);
+struct handler *handler_itr_current(handler_iterator_t itr);
+
+#define for_each_handler(d,i,h)				\
+	for (h = handler_itr_first(d, &(i));	\
+	     h;						\
+	     h = handler_itr_next(&(i)))
+	
+
+handler_list_t handler_list_create(void);
+handler_list_t handler_list_copy(handler_list_t);
+void handler_list_unref(handler_list_t hlist);
+void handler_list_append(handler_list_t hlist,
+				  struct handler *hp);
+size_t handler_list_remove(handler_list_t hlist, struct handler *hp);
+size_t handler_list_size(handler_list_t hlist);
 
 struct process *process_lookup(pid_t pid);
 void process_cleanup(int expect_term);
 void process_timeouts(void);
-int run_handler(struct handler *hp, event_mask *event,
-		const char *dir, const char *file);
 char **environ_setup(char **hint, char **kve);
 
 #define NITEMS(a) ((sizeof(a)/sizeof((a)[0])))
@@ -242,6 +281,11 @@ int sigv_set_all(void (*handler)(int), int sigc, int *sigv,
 int sigv_set_tab(int sigc, struct sigtab *sigtab, struct sigaction *retsa);
 int sigv_set_action_tab(int sigc, struct sigtab *sigtab, struct sigaction *sa);
 
-void filename_pattern_free(void *p);
-int filename_pattern_match(struct grecs_list *lp, const char *name);
+struct grecs_locus;
+int filpatlist_add(filpatlist_t *fptr, char const *arg,
+		   struct grecs_locus *loc);
+void filpatlist_add_exact(filpatlist_t *fptr, char const *arg);
+void filpatlist_destroy(filpatlist_t *fptr);
+int filpatlist_match(filpatlist_t fp, const char *name);
+int filpatlist_is_empty(filpatlist_t fp);
 
