@@ -45,8 +45,67 @@ event_mask genev_xlat[] = {
 
 static int ifd;
 
+static struct watchpoint **wptab;
+static size_t wpsize;
+
+static int
+wpreg(int wd, struct watchpoint *wpt)
+{
+	if (wd < 0)
+		abort();
+	if (wd >= wpsize) {
+		size_t n = wpsize;
+		struct watchpoint **p;
+
+		if (n == 0)
+			n = sysconf(_SC_OPEN_MAX);
+		while (wd >= n) {
+			n *= 2;
+			if (n < wpsize) {
+				diag(LOG_CRIT,
+				     _("can't allocate memory for fd %d"),
+				     wd);
+				return -1;
+			}
+		}
+		p = realloc(wptab, n * sizeof(wptab[0]));
+		if (!p) {
+			diag(LOG_CRIT,
+			     _("can't allocate memory for fd %d"),
+			     wd);
+			return -1;
+		}
+
+		memset(p + wpsize, 0, (n - wpsize) * sizeof(wptab[0]));
+		wptab = p;
+		wpsize = n;
+	}
+	watchpoint_ref(wpt);
+	wptab[wd] = wpt;
+	return 0;
+}
+
+static void
+wpunreg(int wd)
+{
+	if (wd < 0 || wd > wpsize)
+		abort();
+	if (wptab[wd]) {
+		watchpoint_unref(wptab[wd]);
+		wptab[wd] = NULL;
+	}
+}
+
+static struct watchpoint *
+wpget(int wd)
+{
+	if (wd >= 0 && wd < wpsize)
+		return wptab[wd];
+	return NULL;
+}
+
 int
-sysev_filemask(struct dirwatcher *dp)
+sysev_filemask(struct watchpoint *dp)
 {
 	return 0;
 }
@@ -62,46 +121,61 @@ sysev_init()
 }
 
 int
-sysev_add_watch(struct dirwatcher *dwp, event_mask mask)
+sysev_add_watch(struct watchpoint *wpt, event_mask mask)
 {
-	return inotify_add_watch(ifd, dwp->dirname, mask.sys_mask);
+	int wd = inotify_add_watch(ifd, wpt->dirname, mask.sys_mask);
+	if (wd >= 0 && wpreg(wd, wpt)) {
+		inotify_rm_watch(ifd, wd);
+		return -1;
+	}
+	return wd;
 }
 
 void
-sysev_rm_watch(struct dirwatcher *dwp)
+sysev_rm_watch(struct watchpoint *wpt)
 {
-	inotify_rm_watch(ifd, dwp->wd);
+	wpunreg(wpt->wd);
+	inotify_rm_watch(ifd, wpt->wd);
 }
 
 /* Remove a watcher identified by its directory and file name */
 void
 remove_watcher(const char *dir, const char *name)
 {
-	struct dirwatcher *dwp;
+	struct watchpoint *wpt;
 	char *fullname = mkfilename(dir, name);
 	if (!fullname) {
 		diag(LOG_EMERG, "not enough memory: "
 		     "cannot look up a watcher to delete");
 		return;
 	}
-	dwp = dirwatcher_lookup(fullname);
+	wpt = watchpoint_lookup(fullname);
 	free(fullname);
-	if (dwp)
-		dirwatcher_destroy(dwp);
+	if (wpt)
+		watchpoint_suspend(wpt);
 }
 
 static void
 process_event(struct inotify_event *ep)
 {
-	struct dirwatcher *dp;
-	struct handler *h;
-	event_mask m;
+	struct watchpoint *wpt;
 	char *dirname, *filename;
 	
-	dp = dirwatcher_lookup_wd(ep->wd);
-	if (ep->mask & IN_IGNORED)
+	wpt = wpget(ep->wd);
+	if (!wpt) {
+		if (!(ep->mask & IN_IGNORED))
+			diag(LOG_NOTICE, _("watcher not found: %d (%s)"),
+			     ep->wd, ep->name);
 		return;
-	else if (ep->mask & IN_Q_OVERFLOW) {
+	}
+	
+	if (ep->mask & IN_IGNORED) {
+		diag(LOG_NOTICE, _("%s deleted"), wpt->dirname);
+		watchpoint_suspend(wpt);
+		return;
+	}
+	
+	if (ep->mask & IN_Q_OVERFLOW) {
 		diag(LOG_NOTICE,
 		     "event queue overflow");
 		return;
@@ -112,7 +186,7 @@ process_event(struct inotify_event *ep)
 		   were located under the mountpoint
 		*/
 		return;
-	} else if (!dp) {
+	} else if (!wpt) {
 		if (ep->name)
 			diag(LOG_NOTICE, "unrecognized event %x"
 			     "for %s", ep->mask, ep->name);
@@ -122,31 +196,29 @@ process_event(struct inotify_event *ep)
 		return;
 	}
 
-	ev_log(ep->mask, dp);
+	ev_log(ep->mask, wpt);
 
 	if (ep->mask & IN_CREATE) {
-		debug(1, ("%s/%s created", dp->dirname, ep->name));
-		if (check_new_watcher(dp->dirname, ep->name) > 0)
+		debug(1, ("%s/%s created", wpt->dirname, ep->name));
+		if (check_new_watcher(wpt->dirname, ep->name) > 0)
 			return;
-	} else if (ep->mask & (IN_DELETE|IN_MOVED_FROM)) {
-		debug(1, ("%s/%s deleted", dp->dirname, ep->name));
-		remove_watcher(dp->dirname, ep->name);
 	}
 
 	if (ep->len == 0)
-		filename = split_pathname(dp, &dirname);
+		filename = split_pathname(wpt, &dirname);
 	else {
-		dirname = dp->dirname;
+		dirname = wpt->dirname;
 		filename = ep->name;
 	}
-	for (h = dp->handler_list; h; h = h->next) {
-		if (handler_matches_event(h, sys, ep->mask, filename))
-			run_handler(h, event_mask_init(&m,
-						       ep->mask,
-						       &h->ev_mask),
-				    dirname, filename);
+
+	watchpoint_run_handlers(wpt, ep->mask, dirname, filename);
+	
+	unsplit_pathname(wpt);
+
+	if (ep->mask & (IN_DELETE|IN_MOVED_FROM)) {
+		debug(1, ("%s/%s deleted", wpt->dirname, ep->name));
+		remove_watcher(wpt->dirname, ep->name);
 	}
-	unsplit_pathname(dp);
 }	
 
 int
@@ -160,7 +232,7 @@ sysev_select()
 	rdbytes = read(ifd, buffer, sizeof(buffer));
 	if (rdbytes == -1) {
 		if (errno == EINTR) {
-			if (signo == SIGCHLD || signo == SIGALRM)
+			if (!signo || signo == SIGCHLD || signo == SIGALRM)
 				return 0;
 			diag(LOG_NOTICE, "got signal %d", signo);
 			return 1;
