@@ -60,11 +60,12 @@ sysev_init()
 }
 
 int
-sysev_filemask(struct dirwatcher *dp)
+sysev_filemask(struct watchpoint *dp)
 {
 	struct handler *h;
+	handler_iterator_t itr;
 
-	for (h = dp->handler_list; h; h = h->next) {
+	for_each_handler(dp, itr, h) {
 		if (h->ev_mask.sys_mask)
 			return S_IFMT;
 	}
@@ -72,9 +73,9 @@ sysev_filemask(struct dirwatcher *dp)
 }
 
 int
-sysev_add_watch(struct dirwatcher *dwp, event_mask mask)
+sysev_add_watch(struct watchpoint *wpt, event_mask mask)
 {
-	int wd = open(dwp->dirname, O_RDONLY);
+	int wd = open(wpt->dirname, O_RDONLY);
 	if (wd >= 0) {
 		struct stat st;
 		int sysmask;
@@ -83,26 +84,26 @@ sysev_add_watch(struct dirwatcher *dwp, event_mask mask)
 			close(wd);
 			return -1;
 		}
-		dwp->file_mode = st.st_mode;
-		dwp->file_ctime = st.st_ctime;
-		sysmask = mask.sys_mask;
+		wpt->file_mode = st.st_mode;
+		wpt->file_ctime = st.st_ctime;
+		sysmask = mask.sys_mask | NOTE_DELETE;
 		if (S_ISDIR(st.st_mode) && mask.gen_mask & GENEV_CREATE)
 			sysmask |= NOTE_WRITE;
 		EV_SET(chtab + chcnt, wd, EVFILT_VNODE,
 		       EV_ADD | EV_ENABLE | EV_CLEAR, sysmask,
-		       0, dwp);
+		       0, wpt);
 		wd = chcnt++;
 	}
 	return wd;
 }
 
 void
-sysev_rm_watch(struct dirwatcher *dwp)
+sysev_rm_watch(struct watchpoint *wpt)
 {
-	close(chtab[dwp->wd].ident);
-	chtab[dwp->wd].ident = -1;
-	if (chclosed == -1 || chclosed > dwp->wd)
-		chclosed = dwp->wd;
+	close(chtab[wpt->wd].ident);
+	chtab[wpt->wd].ident = -1;
+	if (chclosed == -1 || chclosed > wpt->wd)
+		chclosed = wpt->wd;
 }
 
 static void
@@ -115,11 +116,11 @@ chclosed_elim()
 
 	for (i = chclosed, j = chclosed + 1; j < chcnt; j++)
 		if (chtab[j].ident != -1) {
-			struct dirwatcher *dwp;
+			struct watchpoint *wpt;
 			
 			chtab[i] = chtab[j];
-			dwp = chtab[i].udata;
-			dwp->wd = i;
+			wpt = chtab[i].udata;
+			wpt->wd = i;
 			i++;
 		}
 	chcnt = i;
@@ -127,11 +128,10 @@ chclosed_elim()
 }
 
 static void
-check_created(struct dirwatcher *dp)
+check_created(struct watchpoint *dp)
 {
 	DIR *dir;
 	struct dirent *ent;
-	struct handler *h;
 
 	dir = opendir(dp->dirname);
 	if (!dir) {
@@ -148,6 +148,9 @@ check_created(struct dirwatcher *dp)
 		    (ent->d_name[1] == 0 ||
 		     (ent->d_name[1] == '.' && ent->d_name[2] == 0)))
 			continue;
+
+		if (watchpoint_pattern_match(dp, ent->d_name))
+			continue;
 		
 		pathname = mkfilename(dp->dirname, ent->d_name);
 		if (!pathname) {
@@ -167,10 +170,9 @@ check_created(struct dirwatcher *dp)
 		   know about that file.  If the file is new, register
 		   a watcher for it. */
 		} else if (st.st_ctime > dp->file_ctime ||
-			   !dirwatcher_lookup(pathname)) {
-			deliver_ev_create(dp, ent->d_name);
-			subwatcher_create(dp, pathname,
-					  S_ISDIR(st.st_mode), 1);
+			   !watchpoint_lookup(pathname)) {
+			deliver_ev_create(dp, dp->dirname, ent->d_name);
+			subwatcher_create(dp, pathname, 1);
 			dp->file_ctime = st.st_ctime;
 		}
 		free(pathname);
@@ -181,9 +183,7 @@ check_created(struct dirwatcher *dp)
 static void
 process_event(struct kevent *ep)
 {
-	struct dirwatcher *dp = ep->udata;
-	struct handler *h;
-	event_mask m;
+	struct watchpoint *dp = ep->udata;
 	char *filename, *dirname;
 	
 	if (!dp) {
@@ -193,31 +193,27 @@ process_event(struct kevent *ep)
 
 	ev_log(ep->fflags, dp);
 
-	if (S_ISDIR(dp->file_mode)) {
+	if (S_ISDIR(dp->file_mode)
+	    && !(ep->fflags & (NOTE_DELETE|NOTE_RENAME))) {
 		/* Check if new files have appeared. */
-		if (ep->fflags & NOTE_WRITE)
+		if (ep->fflags & NOTE_WRITE) 
 			check_created(dp);
 		return;
 	}
 
 	filename = split_pathname(dp, &dirname);
-	for (h = dp->handler_list; h; h = h->next) {
-		if (handler_matches_event(h, sys, ep->fflags, filename)) {
-			run_handler(h,
-				    event_mask_init(&m, ep->fflags, &h->ev_mask),
-				    dirname, filename);
-		}
-	}
+
+	watchpoint_run_handlers(dp, ep->fflags, dirname, filename);
+
 	unsplit_pathname(dp);
 	
 	if (ep->fflags & (NOTE_DELETE|NOTE_RENAME)) {
 		debug(1, ("%s deleted", dp->dirname));
-		dirwatcher_destroy(dp);
+		watchpoint_suspend(dp);
 		return;
 	}
 }	
 
-
 int
 sysev_select()
 {
@@ -227,7 +223,7 @@ sysev_select()
 	n = kevent(kq, chtab, chcnt, evtab, chcnt, NULL);
 	if (n == -1) {
 		if (errno == EINTR) {
-			if (signo == SIGCHLD || signo == SIGALRM)
+			if (signo == 0 || signo == SIGCHLD || signo == SIGALRM)
 				return 0;
 			diag(LOG_NOTICE, "got signal %d", signo);
 		}
@@ -237,7 +233,7 @@ sysev_select()
 
 	for (i = 0; i < n; i++) 
 		process_event(&evtab[i]);
-
+		
 	return 0;
 }
 		
