@@ -246,7 +246,7 @@ process_timeouts()
 }
 
 int
-switchpriv(struct handler *hp)
+switchpriv(struct prog_handler *hp)
 {
 	if (hp->uid == 0 || hp->uid == getuid())
 		return 0;
@@ -293,7 +293,7 @@ close_fds(bigfd_set fdset)
 {
 	int i;
 
-	for (i = sysconf(_SC_OPEN_MAX) - 1; i >= 0; i--) {
+	for (i = dup(0); i >= 0; i--) {
 		if (fdset && BIGFD_ISSET(i, fdset))
 			continue;
 		close(i);
@@ -439,24 +439,26 @@ runcmd(const char *cmd, char **envhint, event_mask *event, const char *file,
 	_exit(127);
 }
 
-int
-run_handler(struct handler *hp, event_mask *event,
-	    const char *dirname, const char *file)
+static int
+prog_handler_run(struct watchpoint *wp, event_mask *event,
+		 const char *dirname, const char *file, void *data)
 {
 	pid_t pid;
 	int redir_fd[2] = { -1, -1 };
 	struct process *redir_proc[2] = { NULL, NULL };
 	struct process *p;
+	struct prog_handler *hp = data;
 
-	if (!hp->prog)
+	if (!hp->command)
 		return 0;
 	
-	debug(1, (_("starting %s, dir=%s, file=%s"), hp->prog, dirname, file));
+	debug(1, (_("starting %s, dir=%s, file=%s"),
+		  hp->command, dirname, file));
 	if (hp->flags & HF_STDERR)
-		redir_fd[REDIR_ERR] = open_redirector(hp->prog, LOG_ERR,
+		redir_fd[REDIR_ERR] = open_redirector(hp->command, LOG_ERR,
 						      &redir_proc[REDIR_ERR]);
 	if (hp->flags & HF_STDOUT)
-		redir_fd[REDIR_OUT] = open_redirector(hp->prog, LOG_INFO,
+		redir_fd[REDIR_OUT] = open_redirector(hp->command, LOG_INFO,
 						      &redir_proc[REDIR_OUT]);
 	
 	pid = fork();
@@ -503,12 +505,12 @@ run_handler(struct handler *hp, event_mask *event,
 		close_fds(fdset);
 		alarm(0);
 		signal_setup(SIG_DFL);
-		runcmd(hp->prog, hp->env, event, file, hp->flags & HF_SHELL);
+		runcmd(hp->command, hp->env, event, file, hp->flags & HF_SHELL);
 	}
 
 	/* master */
 	debug(1, (_("%s running; dir=%s, file=%s, pid=%lu"),
-		  hp->prog, dirname, file, (unsigned long)pid));
+		  hp->command, dirname, file, (unsigned long)pid));
 
 	p = register_process(PROC_HANDLER, pid, time(NULL), hp->timeout);
 
@@ -530,7 +532,7 @@ run_handler(struct handler *hp, event_mask *event,
 	}
 
 	debug(1, (_("waiting for %s (%lu) to terminate"),
-		  hp->prog, (unsigned long)pid));
+		  hp->command, (unsigned long)pid));
 	while (time(NULL) - p->start < 2 * p->timeout) {
 		sleep(1);
 		process_cleanup(1);
@@ -539,3 +541,74 @@ run_handler(struct handler *hp, event_mask *event,
 	}
 	return 0;
 }
+
+static void
+envfree(char **env)
+{
+	int i;
+
+	if (!env)
+		return;
+	for (i = 0; env[i]; i++)
+		free(env[i]);
+	free(env);
+}
+
+void
+prog_handler_free(struct prog_handler *hp)
+{
+	free(hp->command);
+	free(hp->gidv);
+	envfree(hp->env);
+}
+
+static void
+prog_handler_free_data(void *ptr)
+{
+	prog_handler_free((struct prog_handler *)ptr);
+}
+
+struct handler *
+prog_handler_alloc(event_mask ev_mask, filpatlist_t fpat,
+		   struct prog_handler *p)
+{
+	struct handler *hp = handler_alloc(ev_mask);
+	struct prog_handler *mem;
+
+	hp->fnames = fpat;
+	hp->run = prog_handler_run;
+	hp->free = prog_handler_free_data;
+	mem = emalloc(sizeof(*mem));
+	*mem = *p;
+	hp->data = mem;
+	memset(p, 0, sizeof(*p));
+	return hp;
+}
+
+/* Reallocate environment of handler HP to accomodate COUNT more
+   entries (not bytes) plus a final NULL entry.
+
+   Return offset of the first unused entry.
+*/
+size_t
+prog_handler_envrealloc(struct prog_handler *hp, size_t count)
+{
+	size_t i;
+
+	if (!hp->env) {
+		hp->env = ecalloc(count + 1, sizeof(hp->env[0]));
+		i = 0;
+	} else {
+		for (i = 0; hp->env[i]; i++)
+			;
+		hp->env = erealloc(hp->env,
+				   (i + count + 1) * sizeof(hp->env[0]));
+		memset(hp->env + i, 0, (count + 1) * sizeof(hp->env[0]));
+	}
+	return i;
+}
+
+
+
+
+		
